Module: Aws::PartnerCentralSelling::Types

Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Defined Under Namespace

Classes: AcceptEngagementInvitationRequest, AccessDeniedException, Account, AccountReceiver, AccountSummary, Address, AddressSummary, AssignOpportunityRequest, AssigneeContact, AssociateOpportunityRequest, AwsOpportunityCustomer, AwsOpportunityInsights, AwsOpportunityLifeCycle, AwsOpportunityProject, AwsOpportunityRelatedEntities, AwsOpportunitySummaryFullView, AwsProductDetails, AwsProductInsights, AwsProductOptimization, AwsProductsSpendInsightsBySource, AwsSubmission, AwsTeamMember, ConflictException, Contact, CreateEngagementContextRequest, CreateEngagementContextResponse, CreateEngagementInvitationRequest, CreateEngagementInvitationResponse, CreateEngagementRequest, CreateEngagementResponse, CreateOpportunityRequest, CreateOpportunityResponse, CreateResourceSnapshotJobRequest, CreateResourceSnapshotJobResponse, CreateResourceSnapshotRequest, CreateResourceSnapshotResponse, CreatedDateFilter, Customer, CustomerProjectsContext, CustomerSummary, DeleteResourceSnapshotJobRequest, DisassociateOpportunityRequest, EngagementContextDetails, EngagementContextPayload, EngagementCustomer, EngagementCustomerProjectDetails, EngagementInvitationSummary, EngagementMember, EngagementMemberSummary, EngagementProspectingResult, EngagementResourceAssociationSummary, EngagementSort, EngagementSummary, ExpectedContractDuration, ExpectedCustomerSpend, GetAwsOpportunitySummaryRequest, GetAwsOpportunitySummaryResponse, GetEngagementInvitationRequest, GetEngagementInvitationResponse, GetEngagementRequest, GetEngagementResponse, GetOpportunityRequest, GetOpportunityResponse, GetProspectingFromEngagementTaskRequest, GetProspectingFromEngagementTaskResponse, GetResourceSnapshotJobRequest, GetResourceSnapshotJobResponse, GetResourceSnapshotRequest, GetResourceSnapshotResponse, GetSellingSystemSettingsRequest, GetSellingSystemSettingsResponse, InternalServerException, Invitation, LastModifiedDate, LeadContact, LeadContext, LeadCustomer, LeadInsights, LeadInteraction, LeadInvitationCustomer, LeadInvitationInteraction, LeadInvitationPayload, LifeCycle, LifeCycleForView, LifeCycleSummary, ListEngagementByAcceptingInvitationTaskSummary, ListEngagementByAcceptingInvitationTasksRequest, ListEngagementByAcceptingInvitationTasksResponse, ListEngagementFromOpportunityTaskSummary, ListEngagementFromOpportunityTasksRequest, ListEngagementFromOpportunityTasksResponse, ListEngagementInvitationsRequest, ListEngagementInvitationsResponse, ListEngagementMembersRequest, ListEngagementMembersResponse, ListEngagementResourceAssociationsRequest, ListEngagementResourceAssociationsResponse, ListEngagementsRequest, ListEngagementsResponse, ListOpportunitiesRequest, ListOpportunitiesResponse, ListOpportunityFromEngagementTaskSummary, ListOpportunityFromEngagementTasksRequest, ListOpportunityFromEngagementTasksResponse, ListProspectingFromEngagementTasksRequest, ListProspectingFromEngagementTasksResponse, ListResourceSnapshotJobsRequest, ListResourceSnapshotJobsResponse, ListResourceSnapshotsRequest, ListResourceSnapshotsResponse, ListSolutionsRequest, ListSolutionsResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTasksSortBase, Marketing, MonetaryValue, NextStepsHistory, OpportunityEngagementInvitationSort, OpportunityInvitationPayload, OpportunityQuality, OpportunitySort, OpportunitySummary, OpportunitySummaryView, Payload, ProfileNextStepsHistory, Project, ProjectDetails, ProjectSummary, ProjectView, ProspectingFromEngagementTaskSort, ProspectingInsights, ProspectingResult, ProspectingResultAws, ProspectingResultCustomer, ProspectingTaskSummary, PutSellingSystemSettingsRequest, PutSellingSystemSettingsResponse, Receiver, Recommendation, RejectEngagementInvitationRequest, RelatedEntityIdentifiers, ResourceNotFoundException, ResourceSnapshotJobSummary, ResourceSnapshotPayload, ResourceSnapshotSummary, SenderContact, ServiceQuotaExceededException, SoftwareRevenue, SolutionBase, SolutionSort, SortObject, StartEngagementByAcceptingInvitationTaskRequest, StartEngagementByAcceptingInvitationTaskResponse, StartEngagementFromOpportunityTaskRequest, StartEngagementFromOpportunityTaskResponse, StartOpportunityFromEngagementTaskRequest, StartOpportunityFromEngagementTaskResponse, StartProspectingFromEngagementTaskRequest, StartProspectingFromEngagementTaskResponse, StartResourceSnapshotJobRequest, StopResourceSnapshotJobRequest, SubmitOpportunityRequest, Tag, TagResourceRequest, TagResourceResponse, TargetCloseDateFilter, ThrottlingException, UntagResourceRequest, UntagResourceResponse, UpdateEngagementContextPayload, UpdateEngagementContextRequest, UpdateEngagementContextResponse, UpdateLeadContext, UpdateOpportunityRequest, UpdateOpportunityResponse, ValidationException, ValidationExceptionError

Instance Attribute Summary collapse

Instance Attribute Details

#accountTypes::AccountReceiver

Specifies the AWS account of the partner who received the Engagement Invitation. This field is used to track the invitation recipient within the AWS ecosystem.



6130
6131
6132
6133
6134
6135
6136
6137
6138
6139
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6130

class Receiver < Struct.new(
  :account,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Account < Receiver; end
  class Unknown < Receiver; end
end

#aws_opportunity_summary_full_viewTypes::AwsOpportunitySummaryFullView

Provides a comprehensive view of AwsOpportunitySummaryFullView template.



6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6350

class ResourceSnapshotPayload < Struct.new(
  :opportunity_summary,
  :aws_opportunity_summary_full_view,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpportunitySummary < ResourceSnapshotPayload; end
  class AwsOpportunitySummaryFullView < ResourceSnapshotPayload; end
  class Unknown < ResourceSnapshotPayload; end
end

#customer_projectTypes::CustomerProjectsContext

The CustomerProjects structure in Engagements offers a flexible framework for managing customer-project relationships. It supports multiple customers per Engagement and multiple projects per customer, while also allowing for customers without projects and projects without specific customers.

All Engagement members have full visibility of customers and their associated projects, enabling the capture of relevant context even when project details are not fully defined. This structure also facilitates targeted invitations, allowing partners to focus on specific customers and their business problems when sending Engagement invitations.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1695

class EngagementContextPayload < Struct.new(
  :customer_project,
  :lead,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerProject < EngagementContextPayload; end
  class Lead < EngagementContextPayload; end
  class ProspectingResult < EngagementContextPayload; end
  class Unknown < EngagementContextPayload; end
end

#leadTypes::UpdateLeadContext

Contains updated information about a lead when the context type is “Lead”. This field is present only when updating a lead context within the engagement.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1695

class EngagementContextPayload < Struct.new(
  :customer_project,
  :lead,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerProject < EngagementContextPayload; end
  class Lead < EngagementContextPayload; end
  class ProspectingResult < EngagementContextPayload; end
  class Unknown < EngagementContextPayload; end
end

#lead_invitationTypes::LeadInvitationPayload

Specifies the details of the lead invitation within the Engagement Invitation payload. This data helps partners understand the lead context, customer information, and interaction history for the lead opportunity from AWS.



5444
5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
5455
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5444

class Payload < Struct.new(
  :opportunity_invitation,
  :lead_invitation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpportunityInvitation < Payload; end
  class LeadInvitation < Payload; end
  class Unknown < Payload; end
end

#opportunity_invitationTypes::OpportunityInvitationPayload

Specifies the details of the opportunity invitation within the Engagement Invitation payload. This data helps partners understand the context, scope, and expected involvement for the opportunity from AWS.



5444
5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
5455
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5444

class Payload < Struct.new(
  :opportunity_invitation,
  :lead_invitation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpportunityInvitation < Payload; end
  class LeadInvitation < Payload; end
  class Unknown < Payload; end
end

#opportunity_summaryTypes::OpportunitySummaryView

An object that contains an ‘opportunity`’s subset of fields.



6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6350

class ResourceSnapshotPayload < Struct.new(
  :opportunity_summary,
  :aws_opportunity_summary_full_view,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpportunitySummary < ResourceSnapshotPayload; end
  class AwsOpportunitySummaryFullView < ResourceSnapshotPayload; end
  class Unknown < ResourceSnapshotPayload; end
end

#prospecting_resultTypes::ProspectingResult

Contains updated prospecting result data when the context type is “ProspectingResult”. This field includes enriched data and insights that the system generates when a partner runs an autonomous prospecting job on leads.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1695

class EngagementContextPayload < Struct.new(
  :customer_project,
  :lead,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerProject < EngagementContextPayload; end
  class Lead < EngagementContextPayload; end
  class ProspectingResult < EngagementContextPayload; end
  class Unknown < EngagementContextPayload; end
end