Class: Aws::PartnerCentralSelling::Types::Account
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::Account
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Specifies the ‘Customer`’s account details associated with the ‘Opportunity`.
Constant Summary collapse
- SENSITIVE =
[:company_name, :website_url, :aws_account_id, :duns]
Instance Attribute Summary collapse
-
#address ⇒ Types::Address
Specifies the end ‘Customer`’s address details associated with the ‘Opportunity`.
-
#aws_account_id ⇒ String
Specifies the ‘Customer` Amazon Web Services account ID associated with the `Opportunity`.
-
#company_name ⇒ String
Specifies the end ‘Customer`’s company name associated with the ‘Opportunity`.
-
#duns ⇒ String
Indicates the ‘Customer` DUNS number, if available.
-
#industry ⇒ String
Specifies the industry the end ‘Customer` belongs to that’s associated with the ‘Opportunity`.
-
#other_industry ⇒ String
Specifies the end ‘Customer`’s industry associated with the ‘Opportunity`, when the selected value in the `Industry` field is `Other`.
-
#website_url ⇒ String
Specifies the end customer’s company website URL associated with the ‘Opportunity`.
Instance Attribute Details
#address ⇒ Types::Address
Specifies the end ‘Customer`’s address details associated with the ‘Opportunity`.
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 102 class Account < Struct.new( :industry, :other_industry, :company_name, :website_url, :aws_account_id, :address, :duns) SENSITIVE = [:company_name, :website_url, :aws_account_id, :duns] include Aws::Structure end |
#aws_account_id ⇒ String
Specifies the ‘Customer` Amazon Web Services account ID associated with the `Opportunity`.
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 102 class Account < Struct.new( :industry, :other_industry, :company_name, :website_url, :aws_account_id, :address, :duns) SENSITIVE = [:company_name, :website_url, :aws_account_id, :duns] include Aws::Structure end |
#company_name ⇒ String
Specifies the end ‘Customer`’s company name associated with the ‘Opportunity`.
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 102 class Account < Struct.new( :industry, :other_industry, :company_name, :website_url, :aws_account_id, :address, :duns) SENSITIVE = [:company_name, :website_url, :aws_account_id, :duns] include Aws::Structure end |
#duns ⇒ String
Indicates the ‘Customer` DUNS number, if available.
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 102 class Account < Struct.new( :industry, :other_industry, :company_name, :website_url, :aws_account_id, :address, :duns) SENSITIVE = [:company_name, :website_url, :aws_account_id, :duns] include Aws::Structure end |
#industry ⇒ String
Specifies the industry the end ‘Customer` belongs to that’s associated with the ‘Opportunity`. It refers to the category or sector where the customer’s business operates. This is a required field.
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 102 class Account < Struct.new( :industry, :other_industry, :company_name, :website_url, :aws_account_id, :address, :duns) SENSITIVE = [:company_name, :website_url, :aws_account_id, :duns] include Aws::Structure end |
#other_industry ⇒ String
Specifies the end ‘Customer`’s industry associated with the ‘Opportunity`, when the selected value in the `Industry` field is `Other`.
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 102 class Account < Struct.new( :industry, :other_industry, :company_name, :website_url, :aws_account_id, :address, :duns) SENSITIVE = [:company_name, :website_url, :aws_account_id, :duns] include Aws::Structure end |
#website_url ⇒ String
Specifies the end customer’s company website URL associated with the ‘Opportunity`. This value is crucial to map the customer within the Amazon Web Services CRM system. This field is required in all cases except when the opportunity is related to national security.
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 102 class Account < Struct.new( :industry, :other_industry, :company_name, :website_url, :aws_account_id, :address, :duns) SENSITIVE = [:company_name, :website_url, :aws_account_id, :duns] include Aws::Structure end |