Class: Aws::PartnerCentralSelling::Types::AssigneeContact

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Represents the contact details of the individual assigned to manage the opportunity within the partner organization. This helps to ensure that there is a point of contact for the opportunity’s progress.

Constant Summary collapse

SENSITIVE =
[:email, :first_name, :last_name, :phone, :business_title]

Instance Attribute Summary collapse

Instance Attribute Details

#business_titleString

Specifies the business title of the assignee managing the opportunity. This helps clarify the individual’s role and responsibilities within the organization. Use the value ‘PartnerAccountManager` to update details of the opportunity owner.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 355

class AssigneeContact < Struct.new(
  :email,
  :first_name,
  :last_name,
  :phone,
  :business_title)
  SENSITIVE = [:email, :first_name, :last_name, :phone, :business_title]
  include Aws::Structure
end

#emailString

Provides the email address of the assignee. This email is used for communications and notifications related to the opportunity.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 355

class AssigneeContact < Struct.new(
  :email,
  :first_name,
  :last_name,
  :phone,
  :business_title)
  SENSITIVE = [:email, :first_name, :last_name, :phone, :business_title]
  include Aws::Structure
end

#first_nameString

Specifies the first name of the assignee managing the opportunity. The system automatically retrieves this value from the user profile by referencing the associated email address.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 355

class AssigneeContact < Struct.new(
  :email,
  :first_name,
  :last_name,
  :phone,
  :business_title)
  SENSITIVE = [:email, :first_name, :last_name, :phone, :business_title]
  include Aws::Structure
end

#last_nameString

Specifies the last name of the assignee managing the opportunity. The system automatically retrieves this value from the user profile by referencing the associated email address.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 355

class AssigneeContact < Struct.new(
  :email,
  :first_name,
  :last_name,
  :phone,
  :business_title)
  SENSITIVE = [:email, :first_name, :last_name, :phone, :business_title]
  include Aws::Structure
end

#phoneString

Specifies the contact phone number of the assignee responsible for the opportunity or engagement. This field enables direct communication for time-sensitive matters and facilitates coordination between AWS and partner teams.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 355

class AssigneeContact < Struct.new(
  :email,
  :first_name,
  :last_name,
  :phone,
  :business_title)
  SENSITIVE = [:email, :first_name, :last_name, :phone, :business_title]
  include Aws::Structure
end