Class: Aws::PartnerCentralSelling::Types::AwsOpportunityInsights

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Contains insights provided by AWS for the opportunity, offering recommendations and analysis that can help the partner optimize their engagement and strategy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_products_spend_insights_by_sourceTypes::AwsProductsSpendInsightsBySource

Source-separated spend insights that provide independent analysis for AWS recommendations and partner estimates.



457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 457

class AwsOpportunityInsights < Struct.new(
  :next_best_actions,
  :engagement_score,
  :aws_products_spend_insights_by_source,
  :opportunity_quality,
  :recommendations)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_scoreString

Represents a score assigned by AWS to indicate the level of engagement and potential success for the opportunity. This score helps partners prioritize their efforts.

Returns:

  • (String)


457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 457

class AwsOpportunityInsights < Struct.new(
  :next_best_actions,
  :engagement_score,
  :aws_products_spend_insights_by_source,
  :opportunity_quality,
  :recommendations)
  SENSITIVE = []
  include Aws::Structure
end

#next_best_actionsString

Provides recommendations from AWS on the next best actions to take in order to move the opportunity forward and increase the likelihood of success.

Returns:

  • (String)


457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 457

class AwsOpportunityInsights < Struct.new(
  :next_best_actions,
  :engagement_score,
  :aws_products_spend_insights_by_source,
  :opportunity_quality,
  :recommendations)
  SENSITIVE = []
  include Aws::Structure
end

#opportunity_qualityTypes::OpportunityQuality

Opportunity quality assessment. Null if not yet scored.



457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 457

class AwsOpportunityInsights < Struct.new(
  :next_best_actions,
  :engagement_score,
  :aws_products_spend_insights_by_source,
  :opportunity_quality,
  :recommendations)
  SENSITIVE = []
  include Aws::Structure
end

#recommendationsArray<Types::Recommendation>

List of recommendations from various agent-driven sources.

Returns:



457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 457

class AwsOpportunityInsights < Struct.new(
  :next_best_actions,
  :engagement_score,
  :aws_products_spend_insights_by_source,
  :opportunity_quality,
  :recommendations)
  SENSITIVE = []
  include Aws::Structure
end