Class: Aws::PartnerCentralSelling::Types::AwsOpportunityProject

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Captures details about the project associated with the opportunity, including objectives, scope, and customer requirements.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_partitionString

AWS partition where the opportunity will be deployed. Possible values: aws-eusc for AWS European Sovereign Cloud, null for all other partitions.

Returns:

  • (String)


538
539
540
541
542
543
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 538

class AwsOpportunityProject < Struct.new(
  :expected_customer_spend,
  :aws_partition)
  SENSITIVE = []
  include Aws::Structure
end

#expected_customer_spendArray<Types::ExpectedCustomerSpend>

Indicates the expected spending by the customer over the course of the project. This value helps partners and AWS estimate the financial impact of the opportunity. Use the AWS Pricing Calculator to create an estimate of the customer’s total spend. If only annual recurring revenue (ARR) is available, distribute it across 12 months to provide an average monthly value.

Returns:



538
539
540
541
542
543
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 538

class AwsOpportunityProject < Struct.new(
  :expected_customer_spend,
  :aws_partition)
  SENSITIVE = []
  include Aws::Structure
end