Class: Aws::PartnerCentralSelling::Types::AwsOpportunityRelatedEntities

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Represents other entities related to the AWS opportunity, such as AWS products, partner solutions, and marketplace offers. These associations help build a complete picture of the solution being sold.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_marketplace_productsArray<String>

The AWS Marketplace product ARNs associated with this opportunity.

Returns:

  • (Array<String>)


571
572
573
574
575
576
577
578
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 571

class AwsOpportunityRelatedEntities < Struct.new(
  :aws_products,
  :solutions,
  :aws_marketplace_solutions,
  :aws_marketplace_products)
  SENSITIVE = []
  include Aws::Structure
end

#aws_marketplace_solutionsArray<String>

The AWS Marketplace solution ARNs associated with this opportunity.

Returns:

  • (Array<String>)


571
572
573
574
575
576
577
578
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 571

class AwsOpportunityRelatedEntities < Struct.new(
  :aws_products,
  :solutions,
  :aws_marketplace_solutions,
  :aws_marketplace_products)
  SENSITIVE = []
  include Aws::Structure
end

#aws_productsArray<String>

Specifies the AWS products associated with the opportunity. This field helps track the specific products that are part of the proposed solution.

Returns:

  • (Array<String>)


571
572
573
574
575
576
577
578
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 571

class AwsOpportunityRelatedEntities < Struct.new(
  :aws_products,
  :solutions,
  :aws_marketplace_solutions,
  :aws_marketplace_products)
  SENSITIVE = []
  include Aws::Structure
end

#solutionsArray<String>

Specifies the partner solutions related to the opportunity. These solutions represent the partner's offerings that are being positioned as part of the overall AWS opportunity.

Returns:

  • (Array<String>)


571
572
573
574
575
576
577
578
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 571

class AwsOpportunityRelatedEntities < Struct.new(
  :aws_products,
  :solutions,
  :aws_marketplace_solutions,
  :aws_marketplace_products)
  SENSITIVE = []
  include Aws::Structure
end