Class: Aws::PartnerCentralSelling::Types::AwsSubmission
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::AwsSubmission
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Indicates the level of AWS involvement in the opportunity. This field helps track AWS participation throughout the engagement, such as providing technical support, deal assistance, and sales support.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#involvement_type ⇒ String
Specifies the type of AWS involvement in the opportunity, such as coselling, deal support, or technical consultation.
-
#visibility ⇒ String
Determines who can view AWS involvement in the opportunity.
Instance Attribute Details
#involvement_type ⇒ String
Specifies the type of AWS involvement in the opportunity, such as coselling, deal support, or technical consultation. This helps categorize the nature of AWS participation.
818 819 820 821 822 823 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 818 class AwsSubmission < Struct.new( :involvement_type, :visibility) SENSITIVE = [] include Aws::Structure end |
#visibility ⇒ String
Determines who can view AWS involvement in the opportunity.
Typically, this field is set to Full for most cases, but it may be
restricted based on special program requirements or confidentiality
needs.
818 819 820 821 822 823 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 818 class AwsSubmission < Struct.new( :involvement_type, :visibility) SENSITIVE = [] include Aws::Structure end |