Class: Aws::PartnerCentralSelling::Types::CreateEngagementInvitationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

Specifies the catalog related to the engagement. Accepted values are AWS and Sandbox, which determine the environment in which the engagement is managed.

Returns:

  • (String)


1003
1004
1005
1006
1007
1008
1009
1010
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1003

class CreateEngagementInvitationRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :invitation)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Specifies a unique, client-generated UUID to ensure that the request is handled exactly once. This token helps prevent duplicate invitation creations.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1003
1004
1005
1006
1007
1008
1009
1010
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1003

class CreateEngagementInvitationRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :invitation)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_identifierString

The unique identifier of the Engagement associated with the invitation. This parameter ensures the invitation is created within the correct Engagement context.

Returns:

  • (String)


1003
1004
1005
1006
1007
1008
1009
1010
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1003

class CreateEngagementInvitationRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :invitation)
  SENSITIVE = []
  include Aws::Structure
end

#invitationTypes::Invitation

The Invitation object all information necessary to initiate an engagement invitation to a partner. It contains a personalized message from the sender, the invitation’s receiver, and a payload. The Payload can be the OpportunityInvitation, which includes detailed structures for sender contacts, partner responsibilities, customer information, and project details, or LeadInvitation, which includes structures for customer information and interaction details.

Returns:



1003
1004
1005
1006
1007
1008
1009
1010
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1003

class CreateEngagementInvitationRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :invitation)
  SENSITIVE = []
  include Aws::Structure
end