Class: Aws::PartnerCentralSelling::Types::CreateEngagementResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::CreateEngagementResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that identifies the engagement.
-
#id ⇒ String
Unique identifier assigned to the newly created engagement.
-
#modified_at ⇒ Time
The timestamp indicating when the engagement was last modified, in ISO 8601 format (UTC).
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) that identifies the engagement.
1102 1103 1104 1105 1106 1107 1108 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1102 class CreateEngagementResponse < Struct.new( :id, :arn, :modified_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Unique identifier assigned to the newly created engagement.
1102 1103 1104 1105 1106 1107 1108 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1102 class CreateEngagementResponse < Struct.new( :id, :arn, :modified_at) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The timestamp indicating when the engagement was last modified, in ISO 8601 format (UTC). For newly created engagements, this value matches the creation timestamp. Example: “2023-05-01T20:37:46Z”.
1102 1103 1104 1105 1106 1107 1108 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1102 class CreateEngagementResponse < Struct.new( :id, :arn, :modified_at) SENSITIVE = [] include Aws::Structure end |