Class: Aws::PartnerCentralSelling::Types::CreateOpportunityResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

Read-only, system-generated Opportunity unique identifier. Amazon Web Services creates this identifier, and it's used for all subsequent opportunity actions, such as updates, associations, and submissions. It helps to ensure that each opportunity is accurately tracked and managed.

Returns:

  • (String)


1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1325

class CreateOpportunityResponse < Struct.new(
  :id,
  :partner_opportunity_identifier,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

DateTime when the opportunity was last modified. When the Opportunity is created, its value is CreatedDate.

Returns:

  • (Time)


1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1325

class CreateOpportunityResponse < Struct.new(
  :id,
  :partner_opportunity_identifier,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#partner_opportunity_identifierString

Specifies the opportunity's unique identifier in the partner's CRM system. This value is essential to track and reconcile because it's included in the outbound payload sent back to the partner.

Returns:

  • (String)


1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1325

class CreateOpportunityResponse < Struct.new(
  :id,
  :partner_opportunity_identifier,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end