Class: Aws::PartnerCentralSelling::Types::CreateResourceSnapshotJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

Specifies the catalog in which to create the snapshot job. Valid values are AWS and ‘ Sandbox`.



1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1343

class CreateResourceSnapshotJobRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :resource_type,
  :resource_identifier,
  :resource_snapshot_template_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A client-generated UUID used for idempotency check. The token helps prevent duplicate job creations.

**A suitable default value is auto-generated.** You should normally not need to pass this option.



1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1343

class CreateResourceSnapshotJobRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :resource_type,
  :resource_identifier,
  :resource_snapshot_template_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_identifierString

Specifies the identifier of the engagement associated with the resource to be snapshotted.



1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1343

class CreateResourceSnapshotJobRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :resource_type,
  :resource_identifier,
  :resource_snapshot_template_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_identifierString

Specifies the identifier of the specific resource to be snapshotted. The format depends on the ‘ ResourceType`.



1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1343

class CreateResourceSnapshotJobRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :resource_type,
  :resource_identifier,
  :resource_snapshot_template_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_snapshot_template_identifierString

Specifies the name of the template that defines the schema for the snapshot.



1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1343

class CreateResourceSnapshotJobRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :resource_type,
  :resource_identifier,
  :resource_snapshot_template_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource for which the snapshot job is being created. Must be one of the supported resource types i.e. Opportunity



1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1343

class CreateResourceSnapshotJobRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :resource_type,
  :resource_identifier,
  :resource_snapshot_template_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A map of the key-value pairs of the tag or tags to assign.



1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1343

class CreateResourceSnapshotJobRequest < Struct.new(
  :catalog,
  :client_token,
  :engagement_identifier,
  :resource_type,
  :resource_identifier,
  :resource_snapshot_template_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end