Class: Aws::PartnerCentralSelling::Types::CreateResourceSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::CreateResourceSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog where the snapshot is created.
-
#client_token ⇒ String
Specifies a unique, client-generated UUID to ensure that the request is handled exactly once.
-
#engagement_identifier ⇒ String
The unique identifier of the engagement associated with this snapshot.
-
#resource_identifier ⇒ String
The unique identifier of the specific resource to be snapshotted.
-
#resource_snapshot_template_identifier ⇒ String
The name of the template that defines the schema for the snapshot.
-
#resource_type ⇒ String
Specifies the type of resource for which the snapshot is being created.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog where the snapshot is created. Valid values are ‘AWS` and `Sandbox`.
1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1434 class CreateResourceSnapshotRequest < Struct.new( :catalog, :engagement_identifier, :resource_type, :resource_identifier, :resource_snapshot_template_identifier, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Specifies a unique, client-generated UUID to ensure that the request is handled exactly once. This token helps prevent duplicate snapshot creations.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1434 class CreateResourceSnapshotRequest < Struct.new( :catalog, :engagement_identifier, :resource_type, :resource_identifier, :resource_snapshot_template_identifier, :client_token) SENSITIVE = [] include Aws::Structure end |
#engagement_identifier ⇒ String
The unique identifier of the engagement associated with this snapshot. This field links the snapshot to a specific engagement context.
1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1434 class CreateResourceSnapshotRequest < Struct.new( :catalog, :engagement_identifier, :resource_type, :resource_identifier, :resource_snapshot_template_identifier, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ String
The unique identifier of the specific resource to be snapshotted. The format and constraints of this identifier depend on the ‘ResourceType` specified. For example: For `Opportunity` type, it will be an opportunity ID.
1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1434 class CreateResourceSnapshotRequest < Struct.new( :catalog, :engagement_identifier, :resource_type, :resource_identifier, :resource_snapshot_template_identifier, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_snapshot_template_identifier ⇒ String
The name of the template that defines the schema for the snapshot. This template determines which subset of the resource data will be included in the snapshot. Must correspond to an existing and valid template for the specified ‘ResourceType`.
1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1434 class CreateResourceSnapshotRequest < Struct.new( :catalog, :engagement_identifier, :resource_type, :resource_identifier, :resource_snapshot_template_identifier, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Specifies the type of resource for which the snapshot is being created. This field determines the structure and content of the snapshot. Must be one of the supported resource types, such as: ‘Opportunity`.
1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1434 class CreateResourceSnapshotRequest < Struct.new( :catalog, :engagement_identifier, :resource_type, :resource_identifier, :resource_snapshot_template_identifier, :client_token) SENSITIVE = [] include Aws::Structure end |