Class: Aws::PartnerCentralSelling::Types::Customer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

An object that contains the customer's Account and Contact.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountTypes::Account

An object that contains the customer's account details.

Returns:



1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1510

class Customer < Struct.new(
  :account,
  :contacts)
  SENSITIVE = []
  include Aws::Structure
end

#contactsArray<Types::Contact>

Represents the contact details for individuals associated with the customer of the Opportunity. This field captures relevant contacts, including decision-makers, influencers, and technical stakeholders within the customer organization. These contacts are key to progressing the opportunity.

Returns:



1510
1511
1512
1513
1514
1515
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1510

class Customer < Struct.new(
  :account,
  :contacts)
  SENSITIVE = []
  include Aws::Structure
end