Class: Aws::PartnerCentralSelling::Types::DisassociateOpportunityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::DisassociateOpportunityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog associated with the request.
-
#opportunity_identifier ⇒ String
The opportunity's unique identifier for when you want to disassociate it from related entities.
-
#related_entity_identifier ⇒ String
The related entity's identifier that you want to disassociate from the opportunity.
-
#related_entity_type ⇒ String
The type of the entity that you're disassociating from the opportunity.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog associated with the request. This field takes
a string value from a predefined list: AWS or Sandbox. The
catalog determines which environment the opportunity disassociation
is made in. Use AWS to disassociate opportunities in the Amazon
Web Services catalog, and Sandbox for testing in secure, isolated
environments.
1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1637 class DisassociateOpportunityRequest < Struct.new( :catalog, :opportunity_identifier, :related_entity_type, :related_entity_identifier) SENSITIVE = [] include Aws::Structure end |
#opportunity_identifier ⇒ String
The opportunity's unique identifier for when you want to disassociate it from related entities. This identifier helps to ensure that the correct opportunity is updated.
Validation: Ensure that the provided identifier corresponds to an existing opportunity in the Amazon Web Services system because incorrect identifiers result in an error and no changes are made.
1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1637 class DisassociateOpportunityRequest < Struct.new( :catalog, :opportunity_identifier, :related_entity_type, :related_entity_identifier) SENSITIVE = [] include Aws::Structure end |
#related_entity_identifier ⇒ String
The related entity's identifier that you want to disassociate from the opportunity. Depending on the type of entity, this could be a simple identifier or an Amazon Resource Name (ARN) for entities managed through Amazon Web Services Marketplace.
For Amazon Web Services Marketplace entities, use the Amazon Web Services Marketplace API to obtain the necessary ARNs. For guidance on retrieving these ARNs, see Amazon Web Services MarketplaceUsing the Amazon Web Services Marketplace Catalog API.
Validation: Ensure the identifier or ARN is valid and corresponds to an existing entity. An incorrect or invalid identifier results in an error.
1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1637 class DisassociateOpportunityRequest < Struct.new( :catalog, :opportunity_identifier, :related_entity_type, :related_entity_identifier) SENSITIVE = [] include Aws::Structure end |
#related_entity_type ⇒ String
The type of the entity that you're disassociating from the opportunity. When you specify the entity type, it helps the system correctly process the disassociation request to ensure that the right connections are removed.
Examples of entity types include Partner Solution, Amazon Web Services product, and Amazon Web Services Marketplaceoffer. Ensure that the value matches one of the expected entity types.
Validation: Provide a valid entity type to help ensure successful disassociation. An invalid or incorrect entity type results in an error.
1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1637 class DisassociateOpportunityRequest < Struct.new( :catalog, :opportunity_identifier, :related_entity_type, :related_entity_identifier) SENSITIVE = [] include Aws::Structure end |