Class: Aws::PartnerCentralSelling::Types::EngagementContextPayload

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Note:

EngagementContextPayload is a union - when making an API calls you must set exactly one of the members.

Note:

EngagementContextPayload is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EngagementContextPayload corresponding to the set member.

Represents the payload of an Engagement context. The structure of this payload varies based on the context type specified in the EngagementContextDetails.

Defined Under Namespace

Classes: CustomerProject, Lead, ProspectingResult, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_projectTypes::CustomerProjectsContext

Contains detailed information about a customer project when the context type is "CustomerProject". This field is present only when the Type in EngagementContextDetails is set to "CustomerProject".



1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1705

class EngagementContextPayload < Struct.new(
  :customer_project,
  :lead,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerProject < EngagementContextPayload; end
  class Lead < EngagementContextPayload; end
  class ProspectingResult < EngagementContextPayload; end
  class Unknown < EngagementContextPayload; end
end

#leadTypes::LeadContext

Contains detailed information about a lead when the context type is "Lead". This field is present only when the Type in EngagementContextDetails is set to "Lead".

Returns:



1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1705

class EngagementContextPayload < Struct.new(
  :customer_project,
  :lead,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerProject < EngagementContextPayload; end
  class Lead < EngagementContextPayload; end
  class ProspectingResult < EngagementContextPayload; end
  class Unknown < EngagementContextPayload; end
end

#prospecting_resultTypes::ProspectingResult

Contains prospecting result data with enriched insights. The system generates these insights when a partner runs an autonomous prospecting job on leads. This field appears only when the context type is "ProspectingResult".



1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1705

class EngagementContextPayload < Struct.new(
  :customer_project,
  :lead,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerProject < EngagementContextPayload; end
  class Lead < EngagementContextPayload; end
  class ProspectingResult < EngagementContextPayload; end
  class Unknown < EngagementContextPayload; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1705
1706
1707
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1705

def unknown
  @unknown
end