Class: Aws::PartnerCentralSelling::Types::EngagementMemberSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

The EngagementMemberSummary provides a snapshot of essential information about participants in an AWS Partner Central Engagement. This compact data structure encapsulates key details of each member, facilitating efficient collaboration and management within the Engagement.

Constant Summary collapse

SENSITIVE =
[:company_name]

Instance Attribute Summary collapse

Instance Attribute Details

#company_nameString

The official name of the member’s company or organization.

Returns:

  • (String)


1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1928

class EngagementMemberSummary < Struct.new(
  :company_name,
  :website_url)
  SENSITIVE = [:company_name]
  include Aws::Structure
end

#website_urlString

The URL of the member company’s website. This offers a way to find more information about the member organization and serves as an additional identifier.

Returns:

  • (String)


1928
1929
1930
1931
1932
1933
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1928

class EngagementMemberSummary < Struct.new(
  :company_name,
  :website_url)
  SENSITIVE = [:company_name]
  include Aws::Structure
end