Class: Aws::PartnerCentralSelling::Types::EngagementProspectingResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Contains the result of processing a single engagement within a prospecting task. Each engagement is processed independently, so individual engagements can succeed or fail regardless of other engagements in the same task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#engagement_context_idString

The identifier of the prospecting context created for this engagement. This field is only populated when the engagement was processed successfully (status is ‘COMPLETED`). Use this identifier to reference the prospecting context in subsequent operations.

Returns:

  • (String)


1969
1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1969

class EngagementProspectingResult < Struct.new(
  :engagement_identifier,
  :engagement_context_id,
  :status,
  :reason_code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_identifierString

The unique identifier of the engagement that was processed.

Returns:

  • (String)


1969
1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1969

class EngagementProspectingResult < Struct.new(
  :engagement_identifier,
  :engagement_context_id,
  :status,
  :reason_code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A human-readable description of the failure for this engagement, including suggested recovery steps. This field is only populated when ‘Status` is `FAILED`.

Returns:

  • (String)


1969
1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1969

class EngagementProspectingResult < Struct.new(
  :engagement_identifier,
  :engagement_context_id,
  :status,
  :reason_code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#reason_codeString

An enumerated code indicating the reason this engagement failed to process. This field is only populated when ‘Status` is `FAILED`.

Returns:

  • (String)


1969
1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1969

class EngagementProspectingResult < Struct.new(
  :engagement_identifier,
  :engagement_context_id,
  :status,
  :reason_code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The processing status of this specific engagement. Possible values are ‘PENDING`, `IN_PROGRESS`, `COMPLETED`, and `FAILED`.

Returns:

  • (String)


1969
1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1969

class EngagementProspectingResult < Struct.new(
  :engagement_identifier,
  :engagement_context_id,
  :status,
  :reason_code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end