Class: Aws::PartnerCentralSelling::Types::ExpectedContractDuration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

The expected duration of a partner’s contract with the customer. Used to convert Total Contract Value (TCV) to Monthly Recurring Revenue (MRR) for opportunity dealsizing calculations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#termString

The unit of measurement for the contract duration value. Currently accepts only ‘Months`.

Returns:

  • (String)


2049
2050
2051
2052
2053
2054
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2049

class ExpectedContractDuration < Struct.new(
  :term,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

A String representation of the contract duration as an integer, expressed in the unit defined by ‘Term`. Valid values range from `1` to `144`.

Returns:

  • (String)


2049
2050
2051
2052
2053
2054
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2049

class ExpectedContractDuration < Struct.new(
  :term,
  :value)
  SENSITIVE = []
  include Aws::Structure
end