Class: Aws::PartnerCentralSelling::Types::GetAwsOpportunitySummaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

Specifies the catalog in which the AWS Opportunity is located. Accepted values include AWS for production opportunities or Sandbox for testing purposes. The catalog determines which environment the opportunity data is pulled from.

Returns:

  • (String)


2205
2206
2207
2208
2209
2210
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2205

class GetAwsOpportunitySummaryRequest < Struct.new(
  :catalog,
  :related_opportunity_identifier)
  SENSITIVE = []
  include Aws::Structure
end

The unique identifier for the related partner opportunity. Use this field to correlate an AWS opportunity with its corresponding partner opportunity.

Returns:

  • (String)


2205
2206
2207
2208
2209
2210
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2205

class GetAwsOpportunitySummaryRequest < Struct.new(
  :catalog,
  :related_opportunity_identifier)
  SENSITIVE = []
  include Aws::Structure
end