Class: Aws::PartnerCentralSelling::Types::GetEngagementInvitationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

Specifies the catalog associated with the request. The field accepts values from the predefined set: AWS for live operations or Sandbox for testing environments.

Returns:

  • (String)


2350
2351
2352
2353
2354
2355
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2350

class GetEngagementInvitationRequest < Struct.new(
  :catalog,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

Specifies the unique identifier for the retrieved engagement invitation.

Returns:

  • (String)


2350
2351
2352
2353
2354
2355
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2350

class GetEngagementInvitationRequest < Struct.new(
  :catalog,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end