Class: Aws::PartnerCentralSelling::Types::GetEngagementInvitationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:sender_aws_account_id, :invitation_message]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) that identifies the engagement invitation.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#catalogString

Indicates the catalog from which the engagement invitation details are retrieved. This field helps in identifying the appropriate catalog (e.g., AWS or Sandbox) used in the request.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#engagement_descriptionString

The description of the engagement associated with this invitation.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#engagement_idString

The identifier of the engagement associated with this invitation.This ID links the invitation to its corresponding engagement.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#engagement_titleString

The title of the engagement invitation, summarizing the purpose or objectives of the opportunity shared by AWS.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#enrichment_contextTypes::EnrichmentContext

The enrichment data for the engagement associated with this invitation. You can view propensity scores, program eligibility, and lead readiness assessments before taking action on the invitation.



2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#existing_membersArray<Types::EngagementMemberSummary>

A list of active members currently part of the Engagement. This array contains a maximum of 10 members, each represented by an object with the following properties.

  • CompanyName: The name of the member's company.

  • WebsiteUrl: The website URL of the member's company.

Returns:



2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#expiration_dateTime

Indicates the date on which the engagement invitation will expire if not accepted by the partner.

Returns:

  • (Time)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#idString

Unique identifier assigned to the engagement invitation being retrieved.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#invitation_dateTime

The date when the engagement invitation was sent to the partner.

Returns:

  • (Time)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#invitation_messageString

The message sent to the invited partner when the invitation was created.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#payloadTypes::Payload

Details of the engagement invitation payload, including specific data relevant to the invitation's contents, such as customer information and opportunity insights.

Returns:



2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#payload_typeString

The type of payload contained in the engagement invitation, indicating what data or context the payload covers.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#receiverTypes::Receiver

Information about the partner organization or team that received the engagement invitation, including contact details and identifiers.

Returns:



2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#rejection_reasonString

If the engagement invitation was rejected, this field specifies the reason provided by the partner for the rejection.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#sender_aws_account_idString

Specifies the AWS Account ID of the sender, which identifies the AWS team responsible for sharing the engagement invitation.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#sender_company_nameString

The name of the AWS organization or team that sent the engagement invitation.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end

#statusString

The current status of the engagement invitation.

Returns:

  • (String)


2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2455

class GetEngagementInvitationResponse < Struct.new(
  :arn,
  :payload_type,
  :id,
  :engagement_id,
  :engagement_title,
  :status,
  :invitation_date,
  :expiration_date,
  :sender_aws_account_id,
  :sender_company_name,
  :receiver,
  :catalog,
  :rejection_reason,
  :payload,
  :invitation_message,
  :engagement_description,
  :existing_members,
  :enrichment_context)
  SENSITIVE = [:sender_aws_account_id, :invitation_message]
  include Aws::Structure
end