Class: Aws::PartnerCentralSelling::Types::GetEngagementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::GetEngagementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog related to the engagement request.
-
#identifier ⇒ String
Specifies the identifier of the Engagement record to retrieve.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog related to the engagement request. Valid values are ‘AWS` and `Sandbox`.
2366 2367 2368 2369 2370 2371 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2366 class GetEngagementRequest < Struct.new( :catalog, :identifier) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
Specifies the identifier of the Engagement record to retrieve.
2366 2367 2368 2369 2370 2371 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2366 class GetEngagementRequest < Struct.new( :catalog, :identifier) SENSITIVE = [] include Aws::Structure end |