Class: Aws::PartnerCentralSelling::Types::GetProspectingFromEngagementTaskResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Represents the response structure containing the full details of a prospecting task, including per-engagement processing results. Includes the ‘Status` field of each `EngagementProspectingResult` entry to determine individual outcomes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

The timestamp indicating when the task finished processing. This field is absent if the task is still in progress. The format follows ISO 8601 date-time notation.

Returns:

  • (Time)


2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2767

class GetProspectingFromEngagementTaskResponse < Struct.new(
  :task_id,
  :task_arn,
  :task_name,
  :start_time,
  :end_time,
  :engagements)
  SENSITIVE = []
  include Aws::Structure
end

#engagementsArray<Types::EngagementProspectingResult>

An array of ‘EngagementProspectingResult` entries for each engagement in the task. Each entry contains the processing status. For successfully completed engagements, includes the prospecting context identifier. For failed engagements, includes an error code and message.



2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2767

class GetProspectingFromEngagementTaskResponse < Struct.new(
  :task_id,
  :task_arn,
  :task_name,
  :start_time,
  :end_time,
  :engagements)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The timestamp indicating when the task was initiated. The format follows ISO 8601 date-time notation.

Returns:

  • (Time)


2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2767

class GetProspectingFromEngagementTaskResponse < Struct.new(
  :task_id,
  :task_arn,
  :task_name,
  :start_time,
  :end_time,
  :engagements)
  SENSITIVE = []
  include Aws::Structure
end

#task_arnString

The Amazon Resource Name (ARN) of the task.

Returns:

  • (String)


2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2767

class GetProspectingFromEngagementTaskResponse < Struct.new(
  :task_id,
  :task_arn,
  :task_name,
  :start_time,
  :end_time,
  :engagements)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier of the task.

Returns:

  • (String)


2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2767

class GetProspectingFromEngagementTaskResponse < Struct.new(
  :task_id,
  :task_arn,
  :task_name,
  :start_time,
  :end_time,
  :engagements)
  SENSITIVE = []
  include Aws::Structure
end

#task_nameString

The descriptive name of the task that you provided when you created it.

Returns:

  • (String)


2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2767

class GetProspectingFromEngagementTaskResponse < Struct.new(
  :task_id,
  :task_arn,
  :task_name,
  :start_time,
  :end_time,
  :engagements)
  SENSITIVE = []
  include Aws::Structure
end