Class: Aws::PartnerCentralSelling::Types::GetResourceSnapshotResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:created_by, :target_member_accounts]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) that uniquely identifies the resource snapshot.

Returns:

  • (String)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#catalogString

The catalog in which the snapshot was created. Matches the Catalog specified in the request.

Returns:

  • (String)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#created_atTime

The timestamp when the snapshot was created, in ISO 8601 format (e.g., ā€œ2023-06-01T14:30:00Zā€). This allows for precise tracking of when the snapshot was taken.

Returns:

  • (Time)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#created_byString

The AWS account ID of the principal (user or role) who created the snapshot. This helps in tracking the origin of the snapshot.

Returns:

  • (String)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#engagement_idString

The identifier of the engagement associated with this snapshot. Matches the EngagementIdentifier specified in the request.

Returns:

  • (String)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#payloadTypes::ResourceSnapshotPayload

Represents the payload of a resource snapshot. This structure is designed to accommodate different types of resource snapshots, currently supporting opportunity summaries.



2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#resource_idString

The identifier of the specific resource that was snapshotted. Matches the ResourceIdentifier specified in the request.

Returns:

  • (String)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#resource_snapshot_template_nameString

The name of the view used for this snapshot. This is the same as the template name.

Returns:

  • (String)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#resource_typeString

The type of the resource that was snapshotted. Matches the ResourceType specified in the request.

Returns:

  • (String)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#revisionInteger

The revision number of this snapshot. This is a positive integer that is sequential and unique within the context of a resource view.

Returns:

  • (Integer)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end

#target_member_accountsArray<String>

Target member accounts associated with the resource snapshot.

Returns:

  • (Array<String>)


2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2844

class GetResourceSnapshotResponse < Struct.new(
  :catalog,
  :arn,
  :created_by,
  :created_at,
  :engagement_id,
  :resource_type,
  :resource_id,
  :resource_snapshot_template_name,
  :revision,
  :payload,
  :target_member_accounts)
  SENSITIVE = [:created_by, :target_member_accounts]
  include Aws::Structure
end