Class: Aws::PartnerCentralSelling::Types::InvitationProspectingResultAws

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

A subset of prospecting result data visible to invitation receivers. It includes customer account details and AI-generated insights.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customerTypes::ProspectingResultCustomer

The prospected customer account details, including geographic classification, industry segmentation, company size, and program eligibility.



3158
3159
3160
3161
3162
3163
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3158

class InvitationProspectingResultAws < Struct.new(
  :customer,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#insightsTypes::ProspectingInsights

The AI-generated insights from the prospecting analysis, including marketplace engagement scoring, solution fit assessments, and solution categorization.



3158
3159
3160
3161
3162
3163
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3158

class InvitationProspectingResultAws < Struct.new(
  :customer,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end