Class: Aws::PartnerCentralSelling::Types::LastModifiedDate
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::LastModifiedDate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Defines a filter to retrieve opportunities based on the last modified date. This filter is useful for tracking changes or updates to opportunities over time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_last_modified_date ⇒ Time
Specifies the date after which the opportunities were modified.
-
#before_last_modified_date ⇒ Time
Specifies the date before which the opportunities were modified.
Instance Attribute Details
#after_last_modified_date ⇒ Time
Specifies the date after which the opportunities were modified. Use this filter to retrieve only those opportunities that were modified after a given timestamp.
2961 2962 2963 2964 2965 2966 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2961 class LastModifiedDate < Struct.new( :after_last_modified_date, :before_last_modified_date) SENSITIVE = [] include Aws::Structure end |
#before_last_modified_date ⇒ Time
Specifies the date before which the opportunities were modified. Use this filter to retrieve only those opportunities that were modified before a given timestamp.
2961 2962 2963 2964 2965 2966 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2961 class LastModifiedDate < Struct.new( :after_last_modified_date, :before_last_modified_date) SENSITIVE = [] include Aws::Structure end |