Class: Aws::PartnerCentralSelling::Types::LeadAddress

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

The address information for a lead customer, including city, state or region, postal code, and country code.

Constant Summary collapse

SENSITIVE =
[:country_code]

Instance Attribute Summary collapse

Instance Attribute Details

#cityString

The city of the lead customer's address.

Returns:

  • (String)


3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3211

class LeadAddress < Struct.new(
  :city,
  :postal_code,
  :state_or_region,
  :country_code)
  SENSITIVE = [:country_code]
  include Aws::Structure
end

#country_codeString

The country code of the lead customer's address.

Returns:

  • (String)


3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3211

class LeadAddress < Struct.new(
  :city,
  :postal_code,
  :state_or_region,
  :country_code)
  SENSITIVE = [:country_code]
  include Aws::Structure
end

#postal_codeString

The postal code of the lead customer's address.

Returns:

  • (String)


3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3211

class LeadAddress < Struct.new(
  :city,
  :postal_code,
  :state_or_region,
  :country_code)
  SENSITIVE = [:country_code]
  include Aws::Structure
end

#state_or_regionString

The state or region of the lead customer's address.

Returns:

  • (String)


3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3211

class LeadAddress < Struct.new(
  :city,
  :postal_code,
  :state_or_region,
  :country_code)
  SENSITIVE = [:country_code]
  include Aws::Structure
end