Class: Aws::PartnerCentralSelling::Types::LeadContact

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

An object that contains a lead contact’s details associated with the engagement. This provides contact information for individuals involved in lead-related activities.

Constant Summary collapse

SENSITIVE =
[:business_title, :email, :first_name, :last_name, :phone]

Instance Attribute Summary collapse

Instance Attribute Details

#business_titleString

The lead contact’s business title or job role associated with the engagement.

Returns:

  • (String)


3152
3153
3154
3155
3156
3157
3158
3159
3160
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3152

class LeadContact < Struct.new(
  :business_title,
  :email,
  :first_name,
  :last_name,
  :phone)
  SENSITIVE = [:business_title, :email, :first_name, :last_name, :phone]
  include Aws::Structure
end

#emailString

The lead contact’s email address associated with the engagement.

Returns:

  • (String)


3152
3153
3154
3155
3156
3157
3158
3159
3160
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3152

class LeadContact < Struct.new(
  :business_title,
  :email,
  :first_name,
  :last_name,
  :phone)
  SENSITIVE = [:business_title, :email, :first_name, :last_name, :phone]
  include Aws::Structure
end

#first_nameString

The lead contact’s first name associated with the engagement.

Returns:

  • (String)


3152
3153
3154
3155
3156
3157
3158
3159
3160
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3152

class LeadContact < Struct.new(
  :business_title,
  :email,
  :first_name,
  :last_name,
  :phone)
  SENSITIVE = [:business_title, :email, :first_name, :last_name, :phone]
  include Aws::Structure
end

#last_nameString

The lead contact’s last name associated with the engagement.

Returns:

  • (String)


3152
3153
3154
3155
3156
3157
3158
3159
3160
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3152

class LeadContact < Struct.new(
  :business_title,
  :email,
  :first_name,
  :last_name,
  :phone)
  SENSITIVE = [:business_title, :email, :first_name, :last_name, :phone]
  include Aws::Structure
end

#phoneString

The lead contact’s phone number associated with the engagement.

Returns:

  • (String)


3152
3153
3154
3155
3156
3157
3158
3159
3160
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3152

class LeadContact < Struct.new(
  :business_title,
  :email,
  :first_name,
  :last_name,
  :phone)
  SENSITIVE = [:business_title, :email, :first_name, :last_name, :phone]
  include Aws::Structure
end