Class: Aws::PartnerCentralSelling::Types::LeadInsights

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Contains insights that AI generates for a lead. These insights provide automated analysis to help partners evaluate the lead quality and prioritize engagement efforts.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lead_readiness_scoreString

A score that indicates the lead's readiness for engagement. Valid values are Low, Medium, and High. Use this score to prioritize leads based on their likelihood of conversion.

Returns:

  • (String)


3277
3278
3279
3280
3281
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3277

class LeadInsights < Struct.new(
  :lead_readiness_score)
  SENSITIVE = []
  include Aws::Structure
end