Class: Aws::PartnerCentralSelling::Types::ListSolutionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

Specifies the catalog associated with the request. This field takes a string value from a predefined list: AWS or Sandbox. The catalog determines which environment the solutions are listed in. Use AWS to list solutions in the Amazon Web Services catalog, and Sandbox to list solutions in a secure and isolated testing environment.

Returns:

  • (String)


4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697

class ListSolutionsRequest < Struct.new(
  :catalog,
  :max_results,
  :next_token,
  :sort,
  :status,
  :identifier,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#categoryArray<String>

Filters the solutions based on the category to which they belong. This allows partners to search for solutions within specific categories, such as Software, Consulting, or ‘Managed Services`.

Returns:

  • (Array<String>)


4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697

class ListSolutionsRequest < Struct.new(
  :catalog,
  :max_results,
  :next_token,
  :sort,
  :status,
  :identifier,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#identifierArray<String>

Filters the solutions based on their unique identifier. Use this filter to retrieve specific solutions by providing the solution’s identifier for accurate results.

Returns:

  • (Array<String>)


4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697

class ListSolutionsRequest < Struct.new(
  :catalog,
  :max_results,
  :next_token,
  :sort,
  :status,
  :identifier,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results returned by a single call. This value must be provided in the next call to retrieve the next set of results.

Default: 20

Returns:

  • (Integer)


4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697

class ListSolutionsRequest < Struct.new(
  :catalog,
  :max_results,
  :next_token,
  :sort,
  :status,
  :identifier,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token used to retrieve the next set of results in subsequent calls. This token is included in the response only if there are additional result pages available.

Returns:

  • (String)


4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697

class ListSolutionsRequest < Struct.new(
  :catalog,
  :max_results,
  :next_token,
  :sort,
  :status,
  :identifier,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#sortTypes::SolutionSort

Object that configures sorting done on the response. Default Sort.SortBy is Identifier.

Returns:



4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697

class ListSolutionsRequest < Struct.new(
  :catalog,
  :max_results,
  :next_token,
  :sort,
  :status,
  :identifier,
  :category)
  SENSITIVE = []
  include Aws::Structure
end

#statusArray<String>

Filters solutions based on their status. This filter helps partners manage their solution portfolios effectively.

Returns:

  • (Array<String>)


4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697

class ListSolutionsRequest < Struct.new(
  :catalog,
  :max_results,
  :next_token,
  :sort,
  :status,
  :identifier,
  :category)
  SENSITIVE = []
  include Aws::Structure
end