Class: Aws::PartnerCentralSelling::Types::OpportunityInvitationPayload

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Represents the data payload of an Engagement Invitation for a specific opportunity. This contains detailed information that partners use to evaluate the engagement.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customerTypes::EngagementCustomer

Contains information about the customer related to the opportunity in the Engagement Invitation. This data helps partners understand the customer’s profile and requirements.



4929
4930
4931
4932
4933
4934
4935
4936
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4929

class OpportunityInvitationPayload < Struct.new(
  :sender_contacts,
  :receiver_responsibilities,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#projectTypes::ProjectDetails

Describes the project details associated with the opportunity, including the customer’s needs and the scope of work expected to be performed.



4929
4930
4931
4932
4933
4934
4935
4936
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4929

class OpportunityInvitationPayload < Struct.new(
  :sender_contacts,
  :receiver_responsibilities,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#receiver_responsibilitiesArray<String>

Outlines the responsibilities or expectations of the receiver in the context of the invitation.

Returns:

  • (Array<String>)


4929
4930
4931
4932
4933
4934
4935
4936
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4929

class OpportunityInvitationPayload < Struct.new(
  :sender_contacts,
  :receiver_responsibilities,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#sender_contactsArray<Types::SenderContact>

Represents the contact details of the AWS representatives involved in sending the Engagement Invitation. These contacts are opportunity stakeholders.

Returns:



4929
4930
4931
4932
4933
4934
4935
4936
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4929

class OpportunityInvitationPayload < Struct.new(
  :sender_contacts,
  :receiver_responsibilities,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end