Class: Aws::PartnerCentralSelling::Types::OpportunityQuality
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::OpportunityQuality
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Opportunity quality score and trend.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#score ⇒ Integer
Deal quality score based on opportunity content completeness and sales methodology criteria.
-
#trend ⇒ String
Direction of score change since last scoring iteration.
Instance Attribute Details
#score ⇒ Integer
Deal quality score based on opportunity content completeness and sales methodology criteria. Values range from 0 to 100.
5271 5272 5273 5274 5275 5276 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5271 class OpportunityQuality < Struct.new( :score, :trend) SENSITIVE = [] include Aws::Structure end |
#trend ⇒ String
Direction of score change since last scoring iteration. Known
values: Improving, Declining, No Change.
5271 5272 5273 5274 5275 5276 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5271 class OpportunityQuality < Struct.new( :score, :trend) SENSITIVE = [] include Aws::Structure end |