Class: Aws::PartnerCentralSelling::Types::ProjectSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::ProjectSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
An object that contains a Project object’s subset of fields.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delivery_models ⇒ Array<String>
Specifies your solution or service’s deployment or consumption model in the
Opportunity‘s context. -
#expected_customer_spend ⇒ Array<Types::ExpectedCustomerSpend>
Provides a summary of the expected customer spend for the project, offering a high-level view of the potential financial impact.
Instance Attribute Details
#delivery_models ⇒ Array<String>
Specifies your solution or service’s deployment or consumption model in the Opportunity‘s context. You can select multiple options.
Options’ descriptions from the ‘Delivery Model` field are:
-
SaaS or PaaS: Your Amazon Web Services based solution deployed as SaaS or PaaS in your Amazon Web Services environment.
-
BYOL or AMI: Your Amazon Web Services based solution deployed as BYOL or AMI in the end customer’s Amazon Web Services environment.
-
Managed Services: The end customer’s Amazon Web Services business management (For example: Consulting, design, implementation, billing support, cost optimization, technical support).
-
Professional Services: Offerings to help enterprise end customers achieve specific business outcomes for enterprise cloud adoption (For example: Advisory or transformation planning).
-
Resell: Amazon Web Services accounts and billing management for your customers.
-
Other: Delivery model not described above.
5404 5405 5406 5407 5408 5409 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5404 class ProjectSummary < Struct.new( :delivery_models, :expected_customer_spend) SENSITIVE = [] include Aws::Structure end |
#expected_customer_spend ⇒ Array<Types::ExpectedCustomerSpend>
Provides a summary of the expected customer spend for the project, offering a high-level view of the potential financial impact.
5404 5405 5406 5407 5408 5409 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5404 class ProjectSummary < Struct.new( :delivery_models, :expected_customer_spend) SENSITIVE = [] include Aws::Structure end |