Class: Aws::PartnerCentralSelling::Types::ProjectView

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Provides the project view of an opportunity resource shared through a snapshot.

Constant Summary collapse

SENSITIVE =
[:other_solution_description]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_use_caseString

Specifies the proposed solution focus or type of workload for the project.

Returns:

  • (String)


5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5895

class ProjectView < Struct.new(
  :delivery_models,
  :expected_customer_spend,
  :expected_contract_duration,
  :customer_use_case,
  :sales_activities,
  :other_solution_description)
  SENSITIVE = [:other_solution_description]
  include Aws::Structure
end

#delivery_modelsArray<String>

Describes the deployment or consumption model for the partner solution or offering. This field indicates how the project's solution will be delivered or implemented for the customer.

Returns:

  • (Array<String>)


5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5895

class ProjectView < Struct.new(
  :delivery_models,
  :expected_customer_spend,
  :expected_contract_duration,
  :customer_use_case,
  :sales_activities,
  :other_solution_description)
  SENSITIVE = [:other_solution_description]
  include Aws::Structure
end

#expected_contract_durationTypes::ExpectedContractDuration

Optional. The expected contract duration for this opportunity, representing the anticipated length of the contract in the unit specified by Term.



5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5895

class ProjectView < Struct.new(
  :delivery_models,
  :expected_customer_spend,
  :expected_contract_duration,
  :customer_use_case,
  :sales_activities,
  :other_solution_description)
  SENSITIVE = [:other_solution_description]
  include Aws::Structure
end

#expected_customer_spendArray<Types::ExpectedCustomerSpend>

Provides information about the anticipated customer spend related to this project. This may include details such as amount, frequency, and currency of expected expenditure.

Returns:



5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5895

class ProjectView < Struct.new(
  :delivery_models,
  :expected_customer_spend,
  :expected_contract_duration,
  :customer_use_case,
  :sales_activities,
  :other_solution_description)
  SENSITIVE = [:other_solution_description]
  include Aws::Structure
end

#other_solution_descriptionString

Offers a description of other solutions if the standard solutions do not adequately cover the project's scope.

Returns:

  • (String)


5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5895

class ProjectView < Struct.new(
  :delivery_models,
  :expected_customer_spend,
  :expected_contract_duration,
  :customer_use_case,
  :sales_activities,
  :other_solution_description)
  SENSITIVE = [:other_solution_description]
  include Aws::Structure
end

#sales_activitiesArray<String>

Lists the pre-sales activities that have occurred with the end-customer related to the opportunity. This field is conditionally mandatory when the project is qualified for Co-Sell and helps drive assignment priority on the AWS side. It provides insight into the engagement level with the customer.

Returns:

  • (Array<String>)


5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5895

class ProjectView < Struct.new(
  :delivery_models,
  :expected_customer_spend,
  :expected_contract_duration,
  :customer_use_case,
  :sales_activities,
  :other_solution_description)
  SENSITIVE = [:other_solution_description]
  include Aws::Structure
end