Class: Aws::PartnerCentralSelling::Types::ProspectingInsights

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Contains insights that AI generates from the prospecting analysis. These insights include marketplace engagement scoring, solution fit assessments, and solution categorization for the prospected customer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#marketplace_engagement_scoreString

A score that indicates the prospected customer's level of engagement with AWS Marketplace. Valid values are High, Medium, and Low.

Returns:

  • (String)


5876
5877
5878
5879
5880
5881
5882
5883
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5876

class ProspectingInsights < Struct.new(
  :marketplace_engagement_score,
  :solution_score,
  :solution_category,
  :solution_sub_category)
  SENSITIVE = []
  include Aws::Structure
end

#solution_categoryString

The primary solution category classification for the prospected customer. This indicates the type of solution that best addresses their needs.

Returns:

  • (String)


5876
5877
5878
5879
5880
5881
5882
5883
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5876

class ProspectingInsights < Struct.new(
  :marketplace_engagement_score,
  :solution_score,
  :solution_category,
  :solution_sub_category)
  SENSITIVE = []
  include Aws::Structure
end

#solution_scoreString

A score that indicates how well the partner's solution fits the prospected customer's needs.

Returns:

  • (String)


5876
5877
5878
5879
5880
5881
5882
5883
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5876

class ProspectingInsights < Struct.new(
  :marketplace_engagement_score,
  :solution_score,
  :solution_category,
  :solution_sub_category)
  SENSITIVE = []
  include Aws::Structure
end

#solution_sub_categoryString

The solution sub-category classification for the prospected customer. This provides more granular categorization of the recommended solution type.

Returns:

  • (String)


5876
5877
5878
5879
5880
5881
5882
5883
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5876

class ProspectingInsights < Struct.new(
  :marketplace_engagement_score,
  :solution_score,
  :solution_category,
  :solution_sub_category)
  SENSITIVE = []
  include Aws::Structure
end