Class: Aws::PartnerCentralSelling::Types::ProspectingResultAws

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Contains the prospecting data that AWS sources. This includes task execution details, customer account information, and insights that AI generates from the prospecting analysis.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customerTypes::ProspectingResultCustomer

Contains details about the prospected customer account, including geographic, industry, and segment classifications.



6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6030

class ProspectingResultAws < Struct.new(
  :customer,
  :insights,
  :start_time,
  :end_time,
  :task_id,
  :task_arn,
  :task_name)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The timestamp when the prospecting task completed processing. The format is ISO 8601 (UTC).

Returns:

  • (Time)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6030

class ProspectingResultAws < Struct.new(
  :customer,
  :insights,
  :start_time,
  :end_time,
  :task_id,
  :task_arn,
  :task_name)
  SENSITIVE = []
  include Aws::Structure
end

#insightsTypes::ProspectingInsights

Insights that AI generates from the prospecting analysis. These insights include engagement scores and solution fit assessments for the prospected customer.



6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6030

class ProspectingResultAws < Struct.new(
  :customer,
  :insights,
  :start_time,
  :end_time,
  :task_id,
  :task_arn,
  :task_name)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The timestamp when the prospecting result context was created. The format is ISO 8601 (UTC).

Returns:

  • (Time)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6030

class ProspectingResultAws < Struct.new(
  :customer,
  :insights,
  :start_time,
  :end_time,
  :task_id,
  :task_arn,
  :task_name)
  SENSITIVE = []
  include Aws::Structure
end

#task_arnString

The Amazon Resource Name (ARN) of the prospecting task. Use this ARN to track and manage the task within AWS.

Returns:

  • (String)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6030

class ProspectingResultAws < Struct.new(
  :customer,
  :insights,
  :start_time,
  :end_time,
  :task_id,
  :task_arn,
  :task_name)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier of the prospecting task that generates this result.

Returns:

  • (String)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6030

class ProspectingResultAws < Struct.new(
  :customer,
  :insights,
  :start_time,
  :end_time,
  :task_id,
  :task_arn,
  :task_name)
  SENSITIVE = []
  include Aws::Structure
end

#task_nameString

The name that the user provides for the prospecting task that generates this result.

Returns:

  • (String)


6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6030

class ProspectingResultAws < Struct.new(
  :customer,
  :insights,
  :start_time,
  :end_time,
  :task_id,
  :task_arn,
  :task_name)
  SENSITIVE = []
  include Aws::Structure
end