Class: Aws::PartnerCentralSelling::Types::ProspectingResultCustomer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Contains detailed information about the prospected customer account, including company identifiers, geographic classification, industry segmentation, and program eligibility.

Constant Summary collapse

SENSITIVE =
[:country]

Instance Attribute Summary collapse

Instance Attribute Details

#account_nameString

The name of the prospected customer account.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#company_sizeString

The company size classification of the prospected customer account.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#countryString

The country code of the prospected customer account.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#eligible_programsArray<String>

A list of AWS Greenfield programs that the prospected customer is eligible for. Use this list to identify relevant go-to-market opportunities.

Returns:

  • (Array<String>)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#geoString

The geographic region classification of the prospected customer account.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#industryString

The industry classification of the prospected customer account.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#public_profile_summaryString

A summary of publicly available information about the prospected customer. The system uses this summary to generate customer insights and inform engagement strategies.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#regionString

The specific region of the prospected customer account.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#segmentString

The market segment classification of the prospected customer account.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#sub_industryString

The sub-industry classification of the prospected customer account. This provides more granular categorization within the primary industry.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end

#sub_regionString

The subregion classification of the prospected customer account.

Returns:

  • (String)


5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5999

class ProspectingResultCustomer < Struct.new(
  :account_name,
  :geo,
  :region,
  :sub_region,
  :country,
  :industry,
  :sub_industry,
  :segment,
  :company_size,
  :eligible_programs,
  :public_profile_summary)
  SENSITIVE = [:country]
  include Aws::Structure
end