Class: Aws::PartnerCentralSelling::Types::Receiver

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Note:

Receiver is a union - when making an API calls you must set exactly one of the members.

Note:

Receiver is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Receiver corresponding to the set member.

Represents the entity that received the Engagement Invitation, including account and company details. This field is essential for tracking the partner who is being invited to collaborate.

Defined Under Namespace

Classes: Account, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountTypes::AccountReceiver

Specifies the AWS account of the partner who received the Engagement Invitation. This field is used to track the invitation recipient within the AWS ecosystem.



6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6231

class Receiver < Struct.new(
  :account,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Account < Receiver; end
  class Unknown < Receiver; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6231
6232
6233
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6231

def unknown
  @unknown
end