Class: Aws::PartnerCentralSelling::Types::ResourceSnapshotJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::ResourceSnapshotJobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
An object that contains a Resource Snapshot Job's subset of fields.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the resource snapshot job.
-
#engagement_id ⇒ String
The unique identifier of the Engagement.
-
#id ⇒ String
The unique identifier for the resource snapshot job within the AWS Partner Central system.
-
#status ⇒ String
The current status of the snapshot job.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the resource snapshot job.
6354 6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6354 class ResourceSnapshotJobSummary < Struct.new( :id, :arn, :engagement_id, :status) SENSITIVE = [] include Aws::Structure end |
#engagement_id ⇒ String
The unique identifier of the Engagement.
6354 6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6354 class ResourceSnapshotJobSummary < Struct.new( :id, :arn, :engagement_id, :status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the resource snapshot job within the AWS Partner Central system. This ID is used for direct references to the job within the service.
6354 6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6354 class ResourceSnapshotJobSummary < Struct.new( :id, :arn, :engagement_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the snapshot job.
Valid values:
-
STOPPED: The job is not currently running.
-
RUNNING: The job is actively executing.
6354 6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6354 class ResourceSnapshotJobSummary < Struct.new( :id, :arn, :engagement_id, :status) SENSITIVE = [] include Aws::Structure end |