Class: Aws::PartnerCentralSelling::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
This error occurs when the request would cause a service quota to be exceeded. Service quotas represent the maximum allowed use of a specific resource, and this error indicates that the request would surpass that limit.
Suggested action: Review the Quotas for the resource, and either reduce usage or request a quota increase.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
6498 6499 6500 6501 6502 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6498 class ServiceQuotaExceededException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |