Class: Aws::PartnerCentralSelling::Types::StartEngagementByAcceptingInvitationTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::StartEngagementByAcceptingInvitationTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engagement_invitation_id ⇒ String
Returns the identifier of the engagement invitation that was accepted and used to create the opportunity.
-
#message ⇒ String
If the task fails, this field contains a detailed message describing the failure and possible recovery steps.
-
#opportunity_id ⇒ String
Returns the original opportunity identifier passed in the request.
-
#reason_code ⇒ String
Indicates the reason for task failure using an enumerated code.
-
#resource_snapshot_job_id ⇒ String
The identifier of the Resource Snapshot Job created as part of this task.
-
#start_time ⇒ Time
The timestamp indicating when the task was initiated.
-
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task, used for tracking and managing the task within AWS.
-
#task_id ⇒ String
The unique identifier of the task, used to track the task’s progress.
-
#task_status ⇒ String
Indicates the current status of the task.
Instance Attribute Details
#engagement_invitation_id ⇒ String
Returns the identifier of the engagement invitation that was accepted and used to create the opportunity.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6100 class StartEngagementByAcceptingInvitationTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
If the task fails, this field contains a detailed message describing the failure and possible recovery steps.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6100 class StartEngagementByAcceptingInvitationTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#opportunity_id ⇒ String
Returns the original opportunity identifier passed in the request. This is the unique identifier for the opportunity.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6100 class StartEngagementByAcceptingInvitationTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#reason_code ⇒ String
Indicates the reason for task failure using an enumerated code.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6100 class StartEngagementByAcceptingInvitationTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#resource_snapshot_job_id ⇒ String
The identifier of the Resource Snapshot Job created as part of this task.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6100 class StartEngagementByAcceptingInvitationTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp indicating when the task was initiated. The format follows RFC 3339 section 5.6.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6100 class StartEngagementByAcceptingInvitationTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task, used for tracking and managing the task within AWS.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6100 class StartEngagementByAcceptingInvitationTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task, used to track the task’s progress.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6100 class StartEngagementByAcceptingInvitationTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#task_status ⇒ String
Indicates the current status of the task.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6100 class StartEngagementByAcceptingInvitationTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |