Class: Aws::PartnerCentralSelling::Types::StartOpportunityFromEngagementTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::StartOpportunityFromEngagementTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog in which the opportunity creation task is executed.
-
#client_token ⇒ String
A unique token provided by the client to help ensure the idempotency of the request.
-
#context_identifier ⇒ String
The unique identifier of the engagement context from which to create the opportunity.
-
#identifier ⇒ String
The unique identifier of the engagement from which the opportunity creation task is to be initiated.
-
#tags ⇒ Array<Types::Tag>
A map of the key-value pairs of the tag or tags to assign.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog in which the opportunity creation task is
executed. Acceptable values include AWS for production and
Sandbox for testing environments.
6886 6887 6888 6889 6890 6891 6892 6893 6894 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6886 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique token provided by the client to help ensure the idempotency of the request. It helps prevent the same task from being performed multiple times.
A suitable default value is auto-generated. You should normally not need to pass this option.
6886 6887 6888 6889 6890 6891 6892 6893 6894 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6886 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#context_identifier ⇒ String
The unique identifier of the engagement context from which to create the opportunity. This specifies the specific contextual information within the engagement that will be used for opportunity creation.
6886 6887 6888 6889 6890 6891 6892 6893 6894 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6886 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the engagement from which the opportunity creation task is to be initiated. This helps ensure that the task is applied to the correct engagement.
6886 6887 6888 6889 6890 6891 6892 6893 6894 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6886 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A map of the key-value pairs of the tag or tags to assign.
6886 6887 6888 6889 6890 6891 6892 6893 6894 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6886 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |