Class: Aws::PartnerCentralSelling::Types::StartOpportunityFromEngagementTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::StartOpportunityFromEngagementTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context_id ⇒ String
The unique identifier of the engagement context used to create the opportunity.
-
#engagement_id ⇒ String
The unique identifier of the engagement from which the opportunity was created.
-
#message ⇒ String
If the task fails, this field contains a detailed message describing the failure and possible recovery steps.
-
#opportunity_id ⇒ String
The unique identifier of the opportunity created as a result of the task.
-
#reason_code ⇒ String
Indicates the reason for task failure using an enumerated code.
-
#resource_snapshot_job_id ⇒ String
The identifier of the resource snapshot job created as part of the opportunity creation process.
-
#start_time ⇒ Time
The timestamp indicating when the task was initiated.
-
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task, used for tracking and managing the task within AWS.
-
#task_id ⇒ String
The unique identifier of the task, used to track the task's progress.
-
#task_status ⇒ String
Indicates the current status of the task.
Instance Attribute Details
#context_id ⇒ String
The unique identifier of the engagement context used to create the opportunity.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#engagement_id ⇒ String
The unique identifier of the engagement from which the opportunity was created.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
If the task fails, this field contains a detailed message describing the failure and possible recovery steps.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#opportunity_id ⇒ String
The unique identifier of the opportunity created as a result of the task. This field is populated when the task is completed successfully.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#reason_code ⇒ String
Indicates the reason for task failure using an enumerated code.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#resource_snapshot_job_id ⇒ String
The identifier of the resource snapshot job created as part of the opportunity creation process.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp indicating when the task was initiated. The format follows RFC 3339 section 5.6.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task, used for tracking and managing the task within AWS.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task, used to track the task's progress.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#task_status ⇒ String
Indicates the current status of the task.
7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7032 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |