Class: Aws::PartnerCentralSelling::Types::StartProspectingFromEngagementTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Represents the request structure for starting a prospecting task. Includes up to 100 engagement identifiers and a task name. Uses ‘ClientToken` to ensure idempotency.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

Specifies the catalog in which the task is initiated. Specify ‘AWS` for production environments and `Sandbox` for testing and development purposes.

Returns:

  • (String)


6959
6960
6961
6962
6963
6964
6965
6966
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6959

class StartProspectingFromEngagementTaskRequest < Struct.new(
  :catalog,
  :identifiers,
  :task_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier provided by the client to ensure idempotency. Making the same request with the same ‘ClientToken` returns the same response without creating a duplicate task.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


6959
6960
6961
6962
6963
6964
6965
6966
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6959

class StartProspectingFromEngagementTaskRequest < Struct.new(
  :catalog,
  :identifiers,
  :task_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifiersArray<String>

The list of engagement identifiers to include in this prospecting task. Each identifier must correspond to an existing engagement in the specified catalog. Maximum of 100 identifiers per task.

Returns:

  • (Array<String>)


6959
6960
6961
6962
6963
6964
6965
6966
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6959

class StartProspectingFromEngagementTaskRequest < Struct.new(
  :catalog,
  :identifiers,
  :task_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_nameString

A descriptive name for the task. This name helps identify the task in list and get operations. The name must contain 1 to 128 characters.

Returns:

  • (String)


6959
6960
6961
6962
6963
6964
6965
6966
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6959

class StartProspectingFromEngagementTaskRequest < Struct.new(
  :catalog,
  :identifiers,
  :task_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end