Class: Aws::PartnerCentralSelling::Types::StartResourceSnapshotJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::StartResourceSnapshotJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog related to the request.
-
#resource_snapshot_job_identifier ⇒ String
The identifier of the resource snapshot job to start.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog related to the request. Valid values are:
-
AWS: Starts the request from the production AWS environment.
-
Sandbox: Starts the request from a sandbox environment used for testing or development purposes.
6350 6351 6352 6353 6354 6355 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6350 class StartResourceSnapshotJobRequest < Struct.new( :catalog, :resource_snapshot_job_identifier) SENSITIVE = [] include Aws::Structure end |
#resource_snapshot_job_identifier ⇒ String
The identifier of the resource snapshot job to start.
6350 6351 6352 6353 6354 6355 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6350 class StartResourceSnapshotJobRequest < Struct.new( :catalog, :resource_snapshot_job_identifier) SENSITIVE = [] include Aws::Structure end |