Class: Aws::PartnerCentralSelling::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
This error occurs when there are too many requests sent. Review the provided quotas and adapt your usage to avoid throttling.
This error occurs when there are too many requests sent. Review the provided Quotas and retry after the provided delay.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
7323 7324 7325 7326 7327 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7323 class ThrottlingException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |