Class: Aws::PartnerCentralSelling::Types::UpdateEngagementContextPayload
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::UpdateEngagementContextPayload
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
UpdateEngagementContextPayload is a union - when making an API calls you must set exactly one of the members.
Represents the updated payload of an engagement context. The structure of this payload varies based on the context type being updated.
Defined Under Namespace
Classes: CustomerProject, Lead, ProspectingResult, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_project ⇒ Types::CustomerProjectsContext
The CustomerProjects structure in Engagements offers a flexible framework for managing customer-project relationships.
-
#lead ⇒ Types::UpdateLeadContext
Contains updated information about a lead when the context type is "Lead".
-
#prospecting_result ⇒ Types::ProspectingResult
Contains updated prospecting result data when the context type is "ProspectingResult".
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#customer_project ⇒ Types::CustomerProjectsContext
The CustomerProjects structure in Engagements offers a flexible framework for managing customer-project relationships. It supports multiple customers per Engagement and multiple projects per customer, while also allowing for customers without projects and projects without specific customers.
All Engagement members have full visibility of customers and their associated projects, enabling the capture of relevant context even when project details are not fully defined. This structure also facilitates targeted invitations, allowing partners to focus on specific customers and their business problems when sending Engagement invitations.
7302 7303 7304 7305 7306 7307 7308 7309 7310 7311 7312 7313 7314 7315 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7302 class UpdateEngagementContextPayload < Struct.new( :lead, :customer_project, :prospecting_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Lead < UpdateEngagementContextPayload; end class CustomerProject < UpdateEngagementContextPayload; end class ProspectingResult < UpdateEngagementContextPayload; end class Unknown < UpdateEngagementContextPayload; end end |
#lead ⇒ Types::UpdateLeadContext
Contains updated information about a lead when the context type is "Lead". This field is present only when updating a lead context within the engagement.
7302 7303 7304 7305 7306 7307 7308 7309 7310 7311 7312 7313 7314 7315 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7302 class UpdateEngagementContextPayload < Struct.new( :lead, :customer_project, :prospecting_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Lead < UpdateEngagementContextPayload; end class CustomerProject < UpdateEngagementContextPayload; end class ProspectingResult < UpdateEngagementContextPayload; end class Unknown < UpdateEngagementContextPayload; end end |
#prospecting_result ⇒ Types::ProspectingResult
Contains updated prospecting result data when the context type is "ProspectingResult". This field includes enriched data and insights that the system generates when a partner runs an autonomous prospecting job on leads.
7302 7303 7304 7305 7306 7307 7308 7309 7310 7311 7312 7313 7314 7315 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7302 class UpdateEngagementContextPayload < Struct.new( :lead, :customer_project, :prospecting_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Lead < UpdateEngagementContextPayload; end class CustomerProject < UpdateEngagementContextPayload; end class ProspectingResult < UpdateEngagementContextPayload; end class Unknown < UpdateEngagementContextPayload; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7302 7303 7304 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7302 def unknown @unknown end |