Class: Aws::PartnerCentralSelling::Types::UpdateEngagementContextRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::UpdateEngagementContextRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog associated with the engagement context update request.
-
#context_identifier ⇒ String
The unique identifier of the specific engagement context to be updated.
-
#engagement_identifier ⇒ String
The unique identifier of the
Engagementcontaining the context to be updated. -
#engagement_last_modified_at ⇒ Time
The timestamp when the engagement was last modified, used for optimistic concurrency control.
-
#payload ⇒ Types::UpdateEngagementContextPayload
Contains the updated contextual information for the engagement.
-
#type ⇒ String
Specifies the type of context being updated within the engagement.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog associated with the engagement context update
request. This field takes a string value from a predefined list:
AWS or Sandbox. The catalog determines which environment the
engagement context is updated in.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7356 class UpdateEngagementContextRequest < Struct.new( :catalog, :engagement_identifier, :context_identifier, :engagement_last_modified_at, :type, :payload) SENSITIVE = [] include Aws::Structure end |
#context_identifier ⇒ String
The unique identifier of the specific engagement context to be updated. This ensures that the correct context within the engagement is modified.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7356 class UpdateEngagementContextRequest < Struct.new( :catalog, :engagement_identifier, :context_identifier, :engagement_last_modified_at, :type, :payload) SENSITIVE = [] include Aws::Structure end |
#engagement_identifier ⇒ String
The unique identifier of the Engagement containing the context to
be updated. This parameter ensures the context update is applied to
the correct engagement.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7356 class UpdateEngagementContextRequest < Struct.new( :catalog, :engagement_identifier, :context_identifier, :engagement_last_modified_at, :type, :payload) SENSITIVE = [] include Aws::Structure end |
#engagement_last_modified_at ⇒ Time
The timestamp when the engagement was last modified, used for optimistic concurrency control. This helps prevent conflicts when multiple users attempt to update the same engagement simultaneously.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7356 class UpdateEngagementContextRequest < Struct.new( :catalog, :engagement_identifier, :context_identifier, :engagement_last_modified_at, :type, :payload) SENSITIVE = [] include Aws::Structure end |
#payload ⇒ Types::UpdateEngagementContextPayload
Contains the updated contextual information for the engagement. The structure of this payload varies based on the context type specified in the Type field.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7356 class UpdateEngagementContextRequest < Struct.new( :catalog, :engagement_identifier, :context_identifier, :engagement_last_modified_at, :type, :payload) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specifies the type of context being updated within the engagement. This field determines the structure and content of the context payload being modified.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7356 class UpdateEngagementContextRequest < Struct.new( :catalog, :engagement_identifier, :context_identifier, :engagement_last_modified_at, :type, :payload) SENSITIVE = [] include Aws::Structure end |