Class: Aws::PartnerCentralSelling::Types::UpdateLeadContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::UpdateLeadContext
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Updates the context information for a lead with qualification status, customer details, and interaction data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer ⇒ Types::LeadCustomer
Updated customer information associated with the lead.
-
#insights ⇒ Types::LeadInsights
Insights that AI generates and associates with the lead.
-
#interaction ⇒ Types::LeadInteraction
Updated interaction details for the lead context.
-
#qualification_status ⇒ String
The updated qualification status of the lead.
Instance Attribute Details
#customer ⇒ Types::LeadCustomer
Updated customer information associated with the lead.
7502 7503 7504 7505 7506 7507 7508 7509 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7502 class UpdateLeadContext < Struct.new( :qualification_status, :customer, :interaction, :insights) SENSITIVE = [] include Aws::Structure end |
#insights ⇒ Types::LeadInsights
Insights that AI generates and associates with the lead. These insights provide automated analysis to help partners assess the lead quality and readiness.
7502 7503 7504 7505 7506 7507 7508 7509 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7502 class UpdateLeadContext < Struct.new( :qualification_status, :customer, :interaction, :insights) SENSITIVE = [] include Aws::Structure end |
#interaction ⇒ Types::LeadInteraction
Updated interaction details for the lead context.
7502 7503 7504 7505 7506 7507 7508 7509 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7502 class UpdateLeadContext < Struct.new( :qualification_status, :customer, :interaction, :insights) SENSITIVE = [] include Aws::Structure end |
#qualification_status ⇒ String
The updated qualification status of the lead.
7502 7503 7504 7505 7506 7507 7508 7509 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7502 class UpdateLeadContext < Struct.new( :qualification_status, :customer, :interaction, :insights) SENSITIVE = [] include Aws::Structure end |