Class: Aws::PartnerCentralSelling::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PartnerCentralSelling::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-partnercentralselling/client.rb
Overview
An API client for PartnerCentralSelling. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::PartnerCentralSelling::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_engagement_invitation(params = {}) ⇒ Struct
Use the ‘AcceptEngagementInvitation` action to accept an engagement invitation shared by AWS.
-
#assign_opportunity(params = {}) ⇒ Struct
Enables you to reassign an existing ‘Opportunity` to another user within your Partner Central account.
-
#associate_opportunity(params = {}) ⇒ Struct
Enables you to create a formal association between an ‘Opportunity` and various related entities, enriching the context and details of the opportunity for better collaboration and decision making.
-
#create_engagement(params = {}) ⇒ Types::CreateEngagementResponse
The ‘CreateEngagement` action allows you to create an `Engagement`, which serves as a collaborative space between different parties such as AWS Partners and AWS Sellers.
-
#create_engagement_context(params = {}) ⇒ Types::CreateEngagementContextResponse
Creates a new context within an existing engagement.
-
#create_engagement_invitation(params = {}) ⇒ Types::CreateEngagementInvitationResponse
This action creates an invitation from a sender to a single receiver to join an engagement.
-
#create_opportunity(params = {}) ⇒ Types::CreateOpportunityResponse
Creates an ‘Opportunity` record in Partner Central.
-
#create_resource_snapshot(params = {}) ⇒ Types::CreateResourceSnapshotResponse
This action allows you to create an immutable snapshot of a specific resource, such as an opportunity, within the context of an engagement.
-
#create_resource_snapshot_job(params = {}) ⇒ Types::CreateResourceSnapshotJobResponse
Use this action to create a job to generate a snapshot of the specified resource within an engagement.
-
#delete_resource_snapshot_job(params = {}) ⇒ Struct
Use this action to deletes a previously created resource snapshot job.
-
#disassociate_opportunity(params = {}) ⇒ Struct
Allows you to remove an existing association between an ‘Opportunity` and related entities, such as a Partner Solution, Amazon Web Services product, or an Amazon Web Services Marketplace offer.
-
#get_aws_opportunity_summary(params = {}) ⇒ Types::GetAwsOpportunitySummaryResponse
Retrieves a summary of an AWS Opportunity.
-
#get_engagement(params = {}) ⇒ Types::GetEngagementResponse
Use this action to retrieve the engagement record for a given ‘EngagementIdentifier`.
-
#get_engagement_invitation(params = {}) ⇒ Types::GetEngagementInvitationResponse
Retrieves the details of an engagement invitation shared by AWS with a partner.
-
#get_opportunity(params = {}) ⇒ Types::GetOpportunityResponse
Fetches the ‘Opportunity` record from Partner Central by a given `Identifier`.
-
#get_resource_snapshot(params = {}) ⇒ Types::GetResourceSnapshotResponse
Use this action to retrieve a specific snapshot record.
-
#get_resource_snapshot_job(params = {}) ⇒ Types::GetResourceSnapshotJobResponse
Use this action to retrieves information about a specific resource snapshot job.
-
#get_selling_system_settings(params = {}) ⇒ Types::GetSellingSystemSettingsResponse
Retrieves the currently set system settings, which include the IAM Role used for resource snapshot jobs.
-
#list_engagement_by_accepting_invitation_tasks(params = {}) ⇒ Types::ListEngagementByAcceptingInvitationTasksResponse
Lists all in-progress, completed, or failed StartEngagementByAcceptingInvitationTask tasks that were initiated by the caller’s account.
-
#list_engagement_from_opportunity_tasks(params = {}) ⇒ Types::ListEngagementFromOpportunityTasksResponse
Lists all in-progress, completed, or failed ‘EngagementFromOpportunity` tasks that were initiated by the caller’s account.
-
#list_engagement_invitations(params = {}) ⇒ Types::ListEngagementInvitationsResponse
Retrieves a list of engagement invitations sent to the partner.
-
#list_engagement_members(params = {}) ⇒ Types::ListEngagementMembersResponse
Retrieves the details of member partners in an Engagement.
-
#list_engagement_resource_associations(params = {}) ⇒ Types::ListEngagementResourceAssociationsResponse
Lists the associations between resources and engagements where the caller is a member and has at least one snapshot in the engagement.
-
#list_engagements(params = {}) ⇒ Types::ListEngagementsResponse
This action allows users to retrieve a list of Engagement records from Partner Central.
-
#list_opportunities(params = {}) ⇒ Types::ListOpportunitiesResponse
This request accepts a list of filters that retrieve opportunity subsets as well as sort options.
-
#list_opportunity_from_engagement_tasks(params = {}) ⇒ Types::ListOpportunityFromEngagementTasksResponse
Lists all in-progress, completed, or failed opportunity creation tasks from engagements that were initiated by the caller’s account.
-
#list_resource_snapshot_jobs(params = {}) ⇒ Types::ListResourceSnapshotJobsResponse
Lists resource snapshot jobs owned by the customer.
-
#list_resource_snapshots(params = {}) ⇒ Types::ListResourceSnapshotsResponse
Retrieves a list of resource view snapshots based on specified criteria.
-
#list_solutions(params = {}) ⇒ Types::ListSolutionsResponse
Retrieves a list of Partner Solutions that the partner registered on Partner Central.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
-
#put_selling_system_settings(params = {}) ⇒ Types::PutSellingSystemSettingsResponse
Updates the currently set system settings, which include the IAM Role used for resource snapshot jobs.
-
#reject_engagement_invitation(params = {}) ⇒ Struct
This action rejects an ‘EngagementInvitation` that AWS shared.
-
#start_engagement_by_accepting_invitation_task(params = {}) ⇒ Types::StartEngagementByAcceptingInvitationTaskResponse
This action starts the engagement by accepting an ‘EngagementInvitation`.
-
#start_engagement_from_opportunity_task(params = {}) ⇒ Types::StartEngagementFromOpportunityTaskResponse
Similar to ‘StartEngagementByAcceptingInvitationTask`, this action is asynchronous and performs multiple steps before completion.
-
#start_opportunity_from_engagement_task(params = {}) ⇒ Types::StartOpportunityFromEngagementTaskResponse
This action creates an opportunity from an existing engagement context.
-
#start_resource_snapshot_job(params = {}) ⇒ Struct
Starts a resource snapshot job that has been previously created.
-
#stop_resource_snapshot_job(params = {}) ⇒ Struct
Stops a resource snapshot job.
-
#submit_opportunity(params = {}) ⇒ Struct
Use this action to submit an Opportunity that was previously created by partner for AWS review.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
-
#update_engagement_context(params = {}) ⇒ Types::UpdateEngagementContextResponse
Updates the context information for an existing engagement with new or modified data.
-
#update_opportunity(params = {}) ⇒ Types::UpdateOpportunityResponse
Updates the ‘Opportunity` record identified by a given `Identifier`.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4229 4230 4231 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 4229 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4232 4233 4234 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 4232 def errors_module Errors end |
Instance Method Details
#accept_engagement_invitation(params = {}) ⇒ Struct
Use the ‘AcceptEngagementInvitation` action to accept an engagement invitation shared by AWS. Accepting the invitation indicates your willingness to participate in the engagement, granting you access to all engagement-related data.
514 515 516 517 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 514 def accept_engagement_invitation(params = {}, = {}) req = build_request(:accept_engagement_invitation, params) req.send_request() end |
#assign_opportunity(params = {}) ⇒ Struct
Enables you to reassign an existing ‘Opportunity` to another user within your Partner Central account. The specified user receives the opportunity, and it appears on their Partner Central dashboard, allowing them to take necessary actions or proceed with the opportunity.
This is useful for distributing opportunities to the appropriate team members or departments within your organization, ensuring that each opportunity is handled by the right person. By default, the opportunity owner is the one who creates it. Currently, there’s no API to enumerate the list of available users.
569 570 571 572 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 569 def assign_opportunity(params = {}, = {}) req = build_request(:assign_opportunity, params) req.send_request() end |
#associate_opportunity(params = {}) ⇒ Struct
Enables you to create a formal association between an ‘Opportunity` and various related entities, enriching the context and details of the opportunity for better collaboration and decision making. You can associate an opportunity with the following entity types:
-
Partner Solution: A software product or consulting practice created and delivered by Partners. Partner Solutions help customers address business challenges using Amazon Web Services services.
-
Amazon Web Services Products: Amazon Web Services offers many products and services that provide scalable, reliable, and cost-effective infrastructure solutions. For the latest list of Amazon Web Services products, see [Amazon Web Services products].
-
Amazon Web Services Marketplace private offer: Allows Amazon Web Services Marketplace sellers to extend custom pricing and terms to individual Amazon Web Services customers. Sellers can negotiate custom prices, payment schedules, and end user license terms through private offers, enabling Amazon Web Services customers to acquire software solutions tailored to their specific needs. For more information, see [Private offers in Amazon Web Services Marketplace].
To obtain identifiers for these entities, use the following methods:
-
Solution: Use the ‘ListSolutions` operation.
-
AWS Products: For the latest list of Amazon Web Services products, see [Amazon Web Services products].
-
Amazon Web Services Marketplace private offer: Use the [Using the Amazon Web Services Marketplace Catalog API] to list entities. Specifically, use the ‘ListEntities` operation to retrieve a list of private offers. The request returns the details of available private offers. For more information, see [ListEntities].
[1]: github.com/aws-samples/partner-crm-integration-samples/blob/main/resources/aws_products.json [2]: docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-private-offers.html [3]: docs.aws.amazon.com/marketplace/latest/APIReference/catalog-apis.html [4]: docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_ListEntities.html
659 660 661 662 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 659 def associate_opportunity(params = {}, = {}) req = build_request(:associate_opportunity, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 4202 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PartnerCentralSelling') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-partnercentralselling' context[:gem_version] = '1.33.0' Seahorse::Client::Request.new(handlers, context) end |
#create_engagement(params = {}) ⇒ Types::CreateEngagementResponse
The ‘CreateEngagement` action allows you to create an `Engagement`, which serves as a collaborative space between different parties such as AWS Partners and AWS Sellers. This action automatically adds the caller’s AWS account as an active member of the newly created ‘Engagement`.
787 788 789 790 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 787 def create_engagement(params = {}, = {}) req = build_request(:create_engagement, params) req.send_request() end |
#create_engagement_context(params = {}) ⇒ Types::CreateEngagementContextResponse
Creates a new context within an existing engagement. This action allows you to add contextual information such as customer projects or documents to an engagement, providing additional details that help facilitate collaboration between engagement members.
909 910 911 912 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 909 def create_engagement_context(params = {}, = {}) req = build_request(:create_engagement_context, params) req.send_request() end |
#create_engagement_invitation(params = {}) ⇒ Types::CreateEngagementInvitationResponse
This action creates an invitation from a sender to a single receiver to join an engagement.
1026 1027 1028 1029 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 1026 def create_engagement_invitation(params = {}, = {}) req = build_request(:create_engagement_invitation, params) req.send_request() end |
#create_opportunity(params = {}) ⇒ Types::CreateOpportunityResponse
Creates an ‘Opportunity` record in Partner Central. Use this operation to create a potential business opportunity for submission to Amazon Web Services. Creating an opportunity sets `Lifecycle.ReviewStatus` to `Pending Submission`.
To submit an opportunity, follow these steps:
-
To create the opportunity, use ‘CreateOpportunity`.
-
To associate a solution with the opportunity, use ‘AssociateOpportunity`.
-
To start the engagement with AWS, use ‘StartEngagementFromOpportunity`.
After submission, you can’t edit the opportunity until the review is complete. But opportunities in the ‘Pending Submission` state must have complete details. You can update the opportunity while it’s in the ‘Pending Submission` state.
There’s a set of mandatory fields to create opportunities, but consider providing optional fields to enrich the opportunity record.
1309 1310 1311 1312 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 1309 def create_opportunity(params = {}, = {}) req = build_request(:create_opportunity, params) req.send_request() end |
#create_resource_snapshot(params = {}) ⇒ Types::CreateResourceSnapshotResponse
This action allows you to create an immutable snapshot of a specific resource, such as an opportunity, within the context of an engagement. The snapshot captures a subset of the resource’s data based on the schema defined by the provided template.
1378 1379 1380 1381 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 1378 def create_resource_snapshot(params = {}, = {}) req = build_request(:create_resource_snapshot, params) req.send_request() end |
#create_resource_snapshot_job(params = {}) ⇒ Types::CreateResourceSnapshotJobResponse
Use this action to create a job to generate a snapshot of the specified resource within an engagement. It initiates an asynchronous process to create a resource snapshot. The job creates a new snapshot only if the resource state has changed, adhering to the same access control and immutability rules as direct snapshot creation.
1450 1451 1452 1453 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 1450 def create_resource_snapshot_job(params = {}, = {}) req = build_request(:create_resource_snapshot_job, params) req.send_request() end |
#delete_resource_snapshot_job(params = {}) ⇒ Struct
Use this action to deletes a previously created resource snapshot job. The job must be in a stopped state before it can be deleted.
1478 1479 1480 1481 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 1478 def delete_resource_snapshot_job(params = {}, = {}) req = build_request(:delete_resource_snapshot_job, params) req.send_request() end |
#disassociate_opportunity(params = {}) ⇒ Struct
Allows you to remove an existing association between an ‘Opportunity` and related entities, such as a Partner Solution, Amazon Web Services product, or an Amazon Web Services Marketplace offer. This operation is the counterpart to `AssociateOpportunity`, and it provides flexibility to manage associations as business needs change.
Use this operation to update the associations of an ‘Opportunity` due to changes in the related entities, or if an association was made in error. Ensuring accurate associations helps maintain clarity and accuracy to track and manage business opportunities. When you replace an entity, first attach the new entity and then disassociate the one to be removed, especially if it’s the last remaining entity that’s required.
1561 1562 1563 1564 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 1561 def disassociate_opportunity(params = {}, = {}) req = build_request(:disassociate_opportunity, params) req.send_request() end |
#get_aws_opportunity_summary(params = {}) ⇒ Types::GetAwsOpportunitySummaryResponse
Retrieves a summary of an AWS Opportunity. This summary includes high-level details about the opportunity sourced from AWS, such as lifecycle information, customer details, and involvement type. It is useful for tracking updates on the AWS opportunity corresponding to an opportunity in the partner’s account.
1685 1686 1687 1688 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 1685 def get_aws_opportunity_summary(params = {}, = {}) req = build_request(:get_aws_opportunity_summary, params) req.send_request() end |
#get_engagement(params = {}) ⇒ Types::GetEngagementResponse
Use this action to retrieve the engagement record for a given ‘EngagementIdentifier`.
1769 1770 1771 1772 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 1769 def get_engagement(params = {}, = {}) req = build_request(:get_engagement, params) req.send_request() end |
#get_engagement_invitation(params = {}) ⇒ Types::GetEngagementInvitationResponse
Retrieves the details of an engagement invitation shared by AWS with a partner. The information includes aspects such as customer, project details, and lifecycle information. To connect an engagement invitation with an opportunity, match the invitation’s ‘Payload.Project.Title` with opportunity `Project.Title`.
1874 1875 1876 1877 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 1874 def get_engagement_invitation(params = {}, = {}) req = build_request(:get_engagement_invitation, params) req.send_request() end |
#get_opportunity(params = {}) ⇒ Types::GetOpportunityResponse
Fetches the ‘Opportunity` record from Partner Central by a given `Identifier`.
Use the ‘ListOpportunities` action or the event notification (from Amazon EventBridge) to obtain this identifier.
2015 2016 2017 2018 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2015 def get_opportunity(params = {}, = {}) req = build_request(:get_opportunity, params) req.send_request() end |
#get_resource_snapshot(params = {}) ⇒ Types::GetResourceSnapshotResponse
Use this action to retrieve a specific snapshot record.
2222 2223 2224 2225 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2222 def get_resource_snapshot(params = {}, = {}) req = build_request(:get_resource_snapshot, params) req.send_request() end |
#get_resource_snapshot_job(params = {}) ⇒ Types::GetResourceSnapshotJobResponse
Use this action to retrieves information about a specific resource snapshot job.
2284 2285 2286 2287 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2284 def get_resource_snapshot_job(params = {}, = {}) req = build_request(:get_resource_snapshot_job, params) req.send_request() end |
#get_selling_system_settings(params = {}) ⇒ Types::GetSellingSystemSettingsResponse
Retrieves the currently set system settings, which include the IAM Role used for resource snapshot jobs.
2317 2318 2319 2320 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2317 def get_selling_system_settings(params = {}, = {}) req = build_request(:get_selling_system_settings, params) req.send_request() end |
#list_engagement_by_accepting_invitation_tasks(params = {}) ⇒ Types::ListEngagementByAcceptingInvitationTasksResponse
Lists all in-progress, completed, or failed StartEngagementByAcceptingInvitationTask tasks that were initiated by the caller’s account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2405 2406 2407 2408 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2405 def list_engagement_by_accepting_invitation_tasks(params = {}, = {}) req = build_request(:list_engagement_by_accepting_invitation_tasks, params) req.send_request() end |
#list_engagement_from_opportunity_tasks(params = {}) ⇒ Types::ListEngagementFromOpportunityTasksResponse
Lists all in-progress, completed, or failed ‘EngagementFromOpportunity` tasks that were initiated by the caller’s account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2495 2496 2497 2498 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2495 def list_engagement_from_opportunity_tasks(params = {}, = {}) req = build_request(:list_engagement_from_opportunity_tasks, params) req.send_request() end |
#list_engagement_invitations(params = {}) ⇒ Types::ListEngagementInvitationsResponse
Retrieves a list of engagement invitations sent to the partner. This allows partners to view all pending or past engagement invitations, helping them track opportunities shared by AWS.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2594 2595 2596 2597 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2594 def list_engagement_invitations(params = {}, = {}) req = build_request(:list_engagement_invitations, params) req.send_request() end |
#list_engagement_members(params = {}) ⇒ Types::ListEngagementMembersResponse
Retrieves the details of member partners in an Engagement. This operation can only be invoked by members of the Engagement. The ‘ListEngagementMembers` operation allows you to fetch information about the members of a specific Engagement. This action is restricted to members of the Engagement being queried.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2645 2646 2647 2648 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2645 def list_engagement_members(params = {}, = {}) req = build_request(:list_engagement_members, params) req.send_request() end |
#list_engagement_resource_associations(params = {}) ⇒ Types::ListEngagementResourceAssociationsResponse
Lists the associations between resources and engagements where the caller is a member and has at least one snapshot in the engagement.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2722 2723 2724 2725 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2722 def list_engagement_resource_associations(params = {}, = {}) req = build_request(:list_engagement_resource_associations, params) req.send_request() end |
#list_engagements(params = {}) ⇒ Types::ListEngagementsResponse
This action allows users to retrieve a list of Engagement records from Partner Central. This action can be used to manage and track various engagements across different stages of the partner selling process.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2811 2812 2813 2814 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2811 def list_engagements(params = {}, = {}) req = build_request(:list_engagements, params) req.send_request() end |
#list_opportunities(params = {}) ⇒ Types::ListOpportunitiesResponse
This request accepts a list of filters that retrieve opportunity subsets as well as sort options. This feature is available to partners from [Partner Central] using the ‘ListOpportunities` API action.
To synchronize your system with Amazon Web Services, list only the opportunities that were newly created or updated. We recommend you rely on events emitted by the service into your Amazon Web Services account’s Amazon EventBridge default event bus. You can also use the ‘ListOpportunities` action.
We recommend the following approach:
-
Find the latest ‘LastModifiedDate` that you stored, and only use the values that came from Amazon Web Services. Don’t use values generated by your system.
-
When you send a ‘ListOpportunities` request, submit the date in ISO 8601 format in the `AfterLastModifiedDate` filter.
-
Amazon Web Services only returns opportunities created or updated on or after that date and time. Use ‘NextToken` to iterate over all pages.
[1]: partnercentral.awspartner.com/
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2977 2978 2979 2980 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 2977 def list_opportunities(params = {}, = {}) req = build_request(:list_opportunities, params) req.send_request() end |
#list_opportunity_from_engagement_tasks(params = {}) ⇒ Types::ListOpportunityFromEngagementTasksResponse
Lists all in-progress, completed, or failed opportunity creation tasks from engagements that were initiated by the caller’s account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3078 3079 3080 3081 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3078 def list_opportunity_from_engagement_tasks(params = {}, = {}) req = build_request(:list_opportunity_from_engagement_tasks, params) req.send_request() end |
#list_resource_snapshot_jobs(params = {}) ⇒ Types::ListResourceSnapshotJobsResponse
Lists resource snapshot jobs owned by the customer. This operation supports various filtering scenarios, including listing all jobs owned by the caller, jobs for a specific engagement, jobs with a specific status, or any combination of these filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3142 3143 3144 3145 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3142 def list_resource_snapshot_jobs(params = {}, = {}) req = build_request(:list_resource_snapshot_jobs, params) req.send_request() end |
#list_resource_snapshots(params = {}) ⇒ Types::ListResourceSnapshotsResponse
Retrieves a list of resource view snapshots based on specified criteria. This operation supports various use cases, including:
-
Fetching all snapshots associated with an engagement.
-
Retrieving snapshots of a specific resource type within an engagement.
-
Obtaining snapshots for a particular resource using a specified template.
-
Accessing the latest snapshot of a resource within an engagement.
-
Filtering snapshots by resource owner.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3225 3226 3227 3228 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3225 def list_resource_snapshots(params = {}, = {}) req = build_request(:list_resource_snapshots, params) req.send_request() end |
#list_solutions(params = {}) ⇒ Types::ListSolutionsResponse
Retrieves a list of Partner Solutions that the partner registered on Partner Central. This API is used to generate a list of solutions that an end user selects from for association with an opportunity.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3308 3309 3310 3311 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3308 def list_solutions(params = {}, = {}) req = build_request(:list_solutions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
3339 3340 3341 3342 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3339 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_selling_system_settings(params = {}) ⇒ Types::PutSellingSystemSettingsResponse
Updates the currently set system settings, which include the IAM Role used for resource snapshot jobs.
3377 3378 3379 3380 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3377 def put_selling_system_settings(params = {}, = {}) req = build_request(:put_selling_system_settings, params) req.send_request() end |
#reject_engagement_invitation(params = {}) ⇒ Struct
This action rejects an ‘EngagementInvitation` that AWS shared. Rejecting an invitation indicates that the partner doesn’t want to pursue the opportunity, and all related data will become inaccessible thereafter.
3430 3431 3432 3433 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3430 def reject_engagement_invitation(params = {}, = {}) req = build_request(:reject_engagement_invitation, params) req.send_request() end |
#start_engagement_by_accepting_invitation_task(params = {}) ⇒ Types::StartEngagementByAcceptingInvitationTaskResponse
This action starts the engagement by accepting an ‘EngagementInvitation`. The task is asynchronous and involves the following steps: accepting the invitation, creating an opportunity in the partner’s account from the AWS opportunity, and copying details for tracking. When completed, an `Opportunity Created` event is generated, indicating that the opportunity has been successfully created in the partner’s account.
3505 3506 3507 3508 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3505 def start_engagement_by_accepting_invitation_task(params = {}, = {}) req = build_request(:start_engagement_by_accepting_invitation_task, params) req.send_request() end |
#start_engagement_from_opportunity_task(params = {}) ⇒ Types::StartEngagementFromOpportunityTaskResponse
Similar to ‘StartEngagementByAcceptingInvitationTask`, this action is asynchronous and performs multiple steps before completion. This action orchestrates a comprehensive workflow that combines multiple API operations into a single task to create and initiate an engagement from an existing opportunity. It automatically executes a sequence of operations including `GetOpportunity`, `CreateEngagement` (if it doesn’t exist), ‘CreateResourceSnapshot`, `CreateResourceSnapshotJob`, `CreateEngagementInvitation` (if not already invited/accepted), and `SubmitOpportunity`.
3594 3595 3596 3597 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3594 def start_engagement_from_opportunity_task(params = {}, = {}) req = build_request(:start_engagement_from_opportunity_task, params) req.send_request() end |
#start_opportunity_from_engagement_task(params = {}) ⇒ Types::StartOpportunityFromEngagementTaskResponse
This action creates an opportunity from an existing engagement context. The task is asynchronous and orchestrates the process of converting engagement contextual information into a structured opportunity record within the partner’s account.
3675 3676 3677 3678 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3675 def start_opportunity_from_engagement_task(params = {}, = {}) req = build_request(:start_opportunity_from_engagement_task, params) req.send_request() end |
#start_resource_snapshot_job(params = {}) ⇒ Struct
Starts a resource snapshot job that has been previously created.
3706 3707 3708 3709 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3706 def start_resource_snapshot_job(params = {}, = {}) req = build_request(:start_resource_snapshot_job, params) req.send_request() end |
#stop_resource_snapshot_job(params = {}) ⇒ Struct
Stops a resource snapshot job. The job must be started prior to being stopped.
3738 3739 3740 3741 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3738 def stop_resource_snapshot_job(params = {}, = {}) req = build_request(:stop_resource_snapshot_job, params) req.send_request() end |
#submit_opportunity(params = {}) ⇒ Struct
Use this action to submit an Opportunity that was previously created by partner for AWS review. After you perform this action, the Opportunity becomes non-editable until it is reviewed by AWS and has ‘ LifeCycle.ReviewStatus ` as either `Approved` or `Action Required`.
3795 3796 3797 3798 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3795 def submit_opportunity(params = {}, = {}) req = build_request(:submit_opportunity, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
3826 3827 3828 3829 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3826 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
3853 3854 3855 3856 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3853 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_engagement_context(params = {}) ⇒ Types::UpdateEngagementContextResponse
Updates the context information for an existing engagement with new or modified data.
3967 3968 3969 3970 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 3967 def update_engagement_context(params = {}, = {}) req = build_request(:update_engagement_context, params) req.send_request() end |
#update_opportunity(params = {}) ⇒ Types::UpdateOpportunityResponse
Updates the ‘Opportunity` record identified by a given `Identifier`. This operation allows you to modify the details of an existing opportunity to reflect the latest information and progress. Use this action to keep the opportunity record up-to-date and accurate.
When you perform updates, include the entire payload with each request. If any field is omitted, the API assumes that the field is set to ‘null`. The best practice is to always perform a `GetOpportunity` to retrieve the latest values, then send the complete payload with the updated values to be changed.
4193 4194 4195 4196 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 4193 def update_opportunity(params = {}, = {}) req = build_request(:update_opportunity, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4222 4223 4224 |
# File 'lib/aws-sdk-partnercentralselling/client.rb', line 4222 def waiter_names [] end |