Class: Aws::PartnerCentralSelling::Types::AssociateOpportunityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::AssociateOpportunityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog associated with the request.
-
#opportunity_identifier ⇒ String
Requires the
Opportunity's unique identifier when you want to associate it with a related entity. -
#related_entity_identifier ⇒ String
Requires the related entity's unique identifier when you want to associate it with the
Opportunity. -
#related_entity_type ⇒ String
Specifies the entity type that you're associating with the
Opportunity.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog associated with the request. This field takes
a string value from a predefined list: AWS or Sandbox. The
catalog determines which environment the opportunity association is
made in. Use AWS to associate opportunities in the Amazon Web
Services catalog, and Sandbox for testing in secure, isolated
environments.
399 400 401 402 403 404 405 406 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 399 class AssociateOpportunityRequest < Struct.new( :catalog, :opportunity_identifier, :related_entity_type, :related_entity_identifier) SENSITIVE = [] include Aws::Structure end |
#opportunity_identifier ⇒ String
Requires the Opportunity's unique identifier when you want to
associate it with a related entity. Provide the correct identifier
so the intended opportunity is updated with the association.
399 400 401 402 403 404 405 406 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 399 class AssociateOpportunityRequest < Struct.new( :catalog, :opportunity_identifier, :related_entity_type, :related_entity_identifier) SENSITIVE = [] include Aws::Structure end |
#related_entity_identifier ⇒ String
Requires the related entity's unique identifier when you want to
associate it with the Opportunity. For Amazon Web Services
Marketplace entities, provide the Amazon Resource Name (ARN). Use
the Amazon Web Services Marketplace API to obtain the ARN.
399 400 401 402 403 404 405 406 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 399 class AssociateOpportunityRequest < Struct.new( :catalog, :opportunity_identifier, :related_entity_type, :related_entity_identifier) SENSITIVE = [] include Aws::Structure end |
#related_entity_type ⇒ String
Specifies the entity type that you're associating with the Opportunity. This helps to categorize and properly process the
association.
399 400 401 402 403 404 405 406 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 399 class AssociateOpportunityRequest < Struct.new( :catalog, :opportunity_identifier, :related_entity_type, :related_entity_identifier) SENSITIVE = [] include Aws::Structure end |