Class: Aws::PartnerCentralSelling::Types::CreateEngagementInvitationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::CreateEngagementInvitationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog related to the engagement.
-
#client_token ⇒ String
Specifies a unique, client-generated UUID to ensure that the request is handled exactly once.
-
#engagement_identifier ⇒ String
The unique identifier of the
Engagementassociated with the invitation. -
#invitation ⇒ Types::Invitation
The
Invitationobject all information necessary to initiate an engagement invitation to a partner.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog related to the engagement. Accepted values are AWS and Sandbox, which determine the environment in which the engagement is managed.
1003 1004 1005 1006 1007 1008 1009 1010 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1003 class CreateEngagementInvitationRequest < Struct.new( :catalog, :client_token, :engagement_identifier, :invitation) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Specifies a unique, client-generated UUID to ensure that the request is handled exactly once. This token helps prevent duplicate invitation creations.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1003 1004 1005 1006 1007 1008 1009 1010 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1003 class CreateEngagementInvitationRequest < Struct.new( :catalog, :client_token, :engagement_identifier, :invitation) SENSITIVE = [] include Aws::Structure end |
#engagement_identifier ⇒ String
The unique identifier of the Engagement associated with the invitation. This parameter ensures the invitation is created within the correct Engagement context.
1003 1004 1005 1006 1007 1008 1009 1010 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1003 class CreateEngagementInvitationRequest < Struct.new( :catalog, :client_token, :engagement_identifier, :invitation) SENSITIVE = [] include Aws::Structure end |
#invitation ⇒ Types::Invitation
The Invitation object all information necessary to initiate an engagement invitation to a partner. It contains a personalized message from the sender, the invitation’s receiver, and a payload. The Payload can be the OpportunityInvitation, which includes detailed structures for sender contacts, partner responsibilities, customer information, and project details, or LeadInvitation, which includes structures for customer information and interaction details.
1003 1004 1005 1006 1007 1008 1009 1010 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1003 class CreateEngagementInvitationRequest < Struct.new( :catalog, :client_token, :engagement_identifier, :invitation) SENSITIVE = [] include Aws::Structure end |