Class: Aws::PartnerCentralSelling::Types::CreateOpportunityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::CreateOpportunityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
Read-only, system-generated ‘Opportunity` unique identifier.
-
#last_modified_date ⇒ Time
‘DateTime` when the opportunity was last modified.
-
#partner_opportunity_identifier ⇒ String
Specifies the opportunity’s unique identifier in the partner’s CRM system.
Instance Attribute Details
#id ⇒ String
Read-only, system-generated ‘Opportunity` unique identifier. Amazon Web Services creates this identifier, and it’s used for all subsequent opportunity actions, such as updates, associations, and submissions. It helps to ensure that each opportunity is accurately tracked and managed.
1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1315 class CreateOpportunityResponse < Struct.new( :id, :partner_opportunity_identifier, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
‘DateTime` when the opportunity was last modified. When the `Opportunity` is created, its value is `CreatedDate`.
1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1315 class CreateOpportunityResponse < Struct.new( :id, :partner_opportunity_identifier, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#partner_opportunity_identifier ⇒ String
Specifies the opportunity’s unique identifier in the partner’s CRM system. This value is essential to track and reconcile because it’s included in the outbound payload sent back to the partner.
1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1315 class CreateOpportunityResponse < Struct.new( :id, :partner_opportunity_identifier, :last_modified_date) SENSITIVE = [] include Aws::Structure end |