Class: Aws::PartnerCentralSelling::Types::EngagementContextPayload

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Note:

EngagementContextPayload is a union - when making an API calls you must set exactly one of the members.

Note:

EngagementContextPayload is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EngagementContextPayload corresponding to the set member.

Represents the payload of an Engagement context. The structure of this payload varies based on the context type specified in the EngagementContextDetails.

Direct Known Subclasses

CustomerProject, Lead, ProspectingResult, Unknown

Defined Under Namespace

Classes: CustomerProject, Lead, ProspectingResult, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_projectTypes::CustomerProjectsContext

Contains detailed information about a customer project when the context type is “CustomerProject”. This field is present only when the Type in EngagementContextDetails is set to “CustomerProject”.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1695

class EngagementContextPayload < Struct.new(
  :customer_project,
  :lead,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerProject < EngagementContextPayload; end
  class Lead < EngagementContextPayload; end
  class ProspectingResult < EngagementContextPayload; end
  class Unknown < EngagementContextPayload; end
end

#leadTypes::LeadContext

Contains detailed information about a lead when the context type is “Lead”. This field is present only when the Type in EngagementContextDetails is set to “Lead”.

Returns:



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1695

class EngagementContextPayload < Struct.new(
  :customer_project,
  :lead,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerProject < EngagementContextPayload; end
  class Lead < EngagementContextPayload; end
  class ProspectingResult < EngagementContextPayload; end
  class Unknown < EngagementContextPayload; end
end

#prospecting_resultTypes::ProspectingResult

Contains prospecting result data with enriched insights. The system generates these insights when a partner runs an autonomous prospecting job on leads. This field appears only when the context type is “ProspectingResult”.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1695

class EngagementContextPayload < Struct.new(
  :customer_project,
  :lead,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerProject < EngagementContextPayload; end
  class Lead < EngagementContextPayload; end
  class ProspectingResult < EngagementContextPayload; end
  class Unknown < EngagementContextPayload; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1695
1696
1697
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 1695

def unknown
  @unknown
end