Class: Aws::PartnerCentralSelling::Types::EnrichmentContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::EnrichmentContext
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Contains enrichment data for engagement invitations. You can view propensity scores, program eligibility, and lead readiness insights directly in the invitation, before you take action on the invitation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lead_insights ⇒ Types::LeadInsights
The AI-generated lead readiness score for this lead.
-
#prospecting_result_aws ⇒ Types::InvitationProspectingResultAws
The customer account data and propensity insights for the prospected account.
Instance Attribute Details
#lead_insights ⇒ Types::LeadInsights
The AI-generated lead readiness score for this lead. Use this score to assess lead quality and prioritize engagement efforts.
2129 2130 2131 2132 2133 2134 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2129 class EnrichmentContext < Struct.new( :prospecting_result_aws, :lead_insights) SENSITIVE = [] include Aws::Structure end |
#prospecting_result_aws ⇒ Types::InvitationProspectingResultAws
The customer account data and propensity insights for the prospected account. It includes geographic, industry, and segment classifications, along with engagement and solution scoring.
2129 2130 2131 2132 2133 2134 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2129 class EnrichmentContext < Struct.new( :prospecting_result_aws, :lead_insights) SENSITIVE = [] include Aws::Structure end |