Class: Aws::PartnerCentralSelling::Types::ExpectedCustomerSpend
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::ExpectedCustomerSpend
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Provides an estimate of the revenue that the partner is expected to generate from the opportunity. This information helps partners assess the financial value of the project.
Constant Summary collapse
- SENSITIVE =
[:amount, :currency_code]
Instance Attribute Summary collapse
-
#amount ⇒ String
Represents the estimated monthly revenue that the partner expects to earn from the opportunity.
-
#currency_code ⇒ String
Indicates the currency in which the revenue estimate is provided.
-
#estimation_url ⇒ String
A URL providing additional information or context about the spend estimation.
-
#frequency ⇒ String
Indicates how frequently the customer is expected to spend the projected amount.
-
#target_company ⇒ String
Specifies the entity associated with this spend entry.
Instance Attribute Details
#amount ⇒ String
Represents the estimated monthly revenue that the partner expects to earn from the opportunity. This helps in forecasting financial returns.
2170 2171 2172 2173 2174 2175 2176 2177 2178 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2170 class ExpectedCustomerSpend < Struct.new( :amount, :currency_code, :frequency, :target_company, :estimation_url) SENSITIVE = [:amount, :currency_code] include Aws::Structure end |
#currency_code ⇒ String
Indicates the currency in which the revenue estimate is provided. This helps in understanding the financial impact across different markets. Accepted values are ‘USD` (US Dollars) and `EUR` (Euros). If the AWS Partition is `aws-eusc` (AWS European Sovereign Cloud), the currency code must be `EUR`.
2170 2171 2172 2173 2174 2175 2176 2177 2178 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2170 class ExpectedCustomerSpend < Struct.new( :amount, :currency_code, :frequency, :target_company, :estimation_url) SENSITIVE = [:amount, :currency_code] include Aws::Structure end |
#estimation_url ⇒ String
A URL providing additional information or context about the spend estimation.
2170 2171 2172 2173 2174 2175 2176 2177 2178 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2170 class ExpectedCustomerSpend < Struct.new( :amount, :currency_code, :frequency, :target_company, :estimation_url) SENSITIVE = [:amount, :currency_code] include Aws::Structure end |
#frequency ⇒ String
Indicates how frequently the customer is expected to spend the projected amount. Use ‘Monthly` for recurring monthly spend (required for `TargetCompany: “AWS”` entries). Use `None` for one-time deal value entries (required for `TargetCompany: “Self”` entries when providing Total Contract Value).
2170 2171 2172 2173 2174 2175 2176 2177 2178 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2170 class ExpectedCustomerSpend < Struct.new( :amount, :currency_code, :frequency, :target_company, :estimation_url) SENSITIVE = [:amount, :currency_code] include Aws::Structure end |
#target_company ⇒ String
Specifies the entity associated with this spend entry. Use ‘AWS` for the system’s AWS Monthly Recurring Revenue (MRR) estimate. Use `Self` for the partner’s own deal value entry when providing Total Contract Value (TCV) for automatic MRR conversion. When `ExpectedContractDuration` is present on the Project, only `AWS` and `Self` are accepted. When `ExpectedContractDuration` is not present, only `AWS` is accepted and any other value will be automatically set to `AWS`.
2170 2171 2172 2173 2174 2175 2176 2177 2178 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2170 class ExpectedCustomerSpend < Struct.new( :amount, :currency_code, :frequency, :target_company, :estimation_url) SENSITIVE = [:amount, :currency_code] include Aws::Structure end |