Class: Aws::PartnerCentralSelling::Types::ExpectedCustomerSpend

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Provides an estimate of the revenue that the partner is expected to generate from the opportunity. This information helps partners assess the financial value of the project.

Constant Summary collapse

SENSITIVE =
[:amount, :currency_code]

Instance Attribute Summary collapse

Instance Attribute Details

#amountString

Represents the estimated monthly revenue that the partner expects to earn from the opportunity. This helps in forecasting financial returns.

Returns:

  • (String)


2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2095

class ExpectedCustomerSpend < Struct.new(
  :amount,
  :currency_code,
  :frequency,
  :target_company,
  :estimation_url)
  SENSITIVE = [:amount, :currency_code]
  include Aws::Structure
end

#currency_codeString

Indicates the currency in which the revenue estimate is provided. This helps in understanding the financial impact across different markets. Accepted values are ‘USD` (US Dollars) and `EUR` (Euros). If the AWS Partition is `aws-eusc` (AWS European Sovereign Cloud), the currency code must be `EUR`.

Returns:

  • (String)


2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2095

class ExpectedCustomerSpend < Struct.new(
  :amount,
  :currency_code,
  :frequency,
  :target_company,
  :estimation_url)
  SENSITIVE = [:amount, :currency_code]
  include Aws::Structure
end

#estimation_urlString

A URL providing additional information or context about the spend estimation.

Returns:

  • (String)


2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2095

class ExpectedCustomerSpend < Struct.new(
  :amount,
  :currency_code,
  :frequency,
  :target_company,
  :estimation_url)
  SENSITIVE = [:amount, :currency_code]
  include Aws::Structure
end

#frequencyString

Indicates how frequently the customer is expected to spend the projected amount. Only the value ‘Monthly` is allowed for the `Frequency` field, representing recurring monthly spend.

Returns:

  • (String)


2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2095

class ExpectedCustomerSpend < Struct.new(
  :amount,
  :currency_code,
  :frequency,
  :target_company,
  :estimation_url)
  SENSITIVE = [:amount, :currency_code]
  include Aws::Structure
end

#target_companyString

Specifies the name of the partner company that is expected to generate revenue from the opportunity. This field helps track the partner’s involvement in the opportunity. This field only accepts the value ‘AWS`. If any other value is provided, the system will automatically set it to `AWS`.

Returns:

  • (String)


2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2095

class ExpectedCustomerSpend < Struct.new(
  :amount,
  :currency_code,
  :frequency,
  :target_company,
  :estimation_url)
  SENSITIVE = [:amount, :currency_code]
  include Aws::Structure
end