Class: Aws::PartnerCentralSelling::Types::GetEngagementInvitationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::GetEngagementInvitationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:sender_aws_account_id, :invitation_message]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that identifies the engagement invitation.
-
#catalog ⇒ String
Indicates the catalog from which the engagement invitation details are retrieved.
-
#engagement_description ⇒ String
The description of the engagement associated with this invitation.
-
#engagement_id ⇒ String
The identifier of the engagement associated with this invitation.This ID links the invitation to its corresponding engagement.
-
#engagement_title ⇒ String
The title of the engagement invitation, summarizing the purpose or objectives of the opportunity shared by AWS.
-
#existing_members ⇒ Array<Types::EngagementMemberSummary>
A list of active members currently part of the Engagement.
-
#expiration_date ⇒ Time
Indicates the date on which the engagement invitation will expire if not accepted by the partner.
-
#id ⇒ String
Unique identifier assigned to the engagement invitation being retrieved.
-
#invitation_date ⇒ Time
The date when the engagement invitation was sent to the partner.
-
#invitation_message ⇒ String
The message sent to the invited partner when the invitation was created.
-
#payload ⇒ Types::Payload
Details of the engagement invitation payload, including specific data relevant to the invitation’s contents, such as customer information and opportunity insights.
-
#payload_type ⇒ String
The type of payload contained in the engagement invitation, indicating what data or context the payload covers.
-
#receiver ⇒ Types::Receiver
Information about the partner organization or team that received the engagement invitation, including contact details and identifiers.
-
#rejection_reason ⇒ String
If the engagement invitation was rejected, this field specifies the reason provided by the partner for the rejection.
-
#sender_aws_account_id ⇒ String
Specifies the AWS Account ID of the sender, which identifies the AWS team responsible for sharing the engagement invitation.
-
#sender_company_name ⇒ String
The name of the AWS organization or team that sent the engagement invitation.
-
#status ⇒ String
The current status of the engagement invitation.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) that identifies the engagement invitation.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#catalog ⇒ String
Indicates the catalog from which the engagement invitation details are retrieved. This field helps in identifying the appropriate catalog (e.g., ‘AWS` or `Sandbox`) used in the request.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#engagement_description ⇒ String
The description of the engagement associated with this invitation.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#engagement_id ⇒ String
The identifier of the engagement associated with this invitation.This ID links the invitation to its corresponding engagement.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#engagement_title ⇒ String
The title of the engagement invitation, summarizing the purpose or objectives of the opportunity shared by AWS.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#existing_members ⇒ Array<Types::EngagementMemberSummary>
A list of active members currently part of the Engagement. This array contains a maximum of 10 members, each represented by an object with the following properties.
-
CompanyName: The name of the member’s company.
-
WebsiteUrl: The website URL of the member’s company.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#expiration_date ⇒ Time
Indicates the date on which the engagement invitation will expire if not accepted by the partner.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#id ⇒ String
Unique identifier assigned to the engagement invitation being retrieved.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#invitation_date ⇒ Time
The date when the engagement invitation was sent to the partner.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#invitation_message ⇒ String
The message sent to the invited partner when the invitation was created.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#payload ⇒ Types::Payload
Details of the engagement invitation payload, including specific data relevant to the invitation’s contents, such as customer information and opportunity insights.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#payload_type ⇒ String
The type of payload contained in the engagement invitation, indicating what data or context the payload covers.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#receiver ⇒ Types::Receiver
Information about the partner organization or team that received the engagement invitation, including contact details and identifiers.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#rejection_reason ⇒ String
If the engagement invitation was rejected, this field specifies the reason provided by the partner for the rejection.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#sender_aws_account_id ⇒ String
Specifies the AWS Account ID of the sender, which identifies the AWS team responsible for sharing the engagement invitation.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#sender_company_name ⇒ String
The name of the AWS organization or team that sent the engagement invitation.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |
#status ⇒ String
The current status of the engagement invitation.
2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2415 class GetEngagementInvitationResponse < Struct.new( :arn, :payload_type, :id, :engagement_id, :engagement_title, :status, :invitation_date, :expiration_date, :sender_aws_account_id, :sender_company_name, :receiver, :catalog, :rejection_reason, :payload, :invitation_message, :engagement_description, :existing_members) SENSITIVE = [:sender_aws_account_id, :invitation_message] include Aws::Structure end |