Class: Aws::PartnerCentralSelling::Types::GetOpportunityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

Specifies the catalog associated with the request. This field takes a string value from a predefined list: AWS or Sandbox. The catalog determines which environment the opportunity is fetched from. Use AWS to retrieve opportunities in the Amazon Web Services catalog, and Sandbox to retrieve opportunities in a secure, isolated testing environment.

Returns:

  • (String)


2552
2553
2554
2555
2556
2557
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2552

class GetOpportunityRequest < Struct.new(
  :catalog,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

Read-only, system generated Opportunity unique identifier.

Returns:

  • (String)


2552
2553
2554
2555
2556
2557
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2552

class GetOpportunityRequest < Struct.new(
  :catalog,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end