Class: Aws::PartnerCentralSelling::Types::GetOpportunityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::GetOpportunityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the opportunity.
-
#catalog ⇒ String
Specifies the catalog associated with the request.
-
#created_date ⇒ Time
DateTimewhen theOpportunitywas last created. -
#customer ⇒ Types::Customer
Specifies details of the customer associated with the
Opportunity. -
#id ⇒ String
Read-only, system generated
Opportunityunique identifier. -
#last_modified_date ⇒ Time
DateTimewhen the opportunity was last modified. -
#life_cycle ⇒ Types::LifeCycle
An object that contains lifecycle details for the
Opportunity. -
#marketing ⇒ Types::Marketing
An object that contains marketing details for the
Opportunity. -
#national_security ⇒ String
Indicates whether the
Opportunitypertains to a national security project. -
#opportunity_team ⇒ Array<Types::Contact>
Represents the internal team handling the opportunity.
-
#opportunity_type ⇒ String
Specifies the opportunity type as renewal, new, or expansion.
-
#partner_opportunity_identifier ⇒ String
Specifies the opportunity's unique identifier in the partner's CRM system.
-
#primary_needs_from_aws ⇒ Array<String>
Identifies the type of support the partner needs from Amazon Web Services.
-
#project ⇒ Types::Project
An object that contains project details summary for the
Opportunity. -
#related_entity_identifiers ⇒ Types::RelatedEntityIdentifiers
Provides information about the associations of other entities with the opportunity.
-
#software_revenue ⇒ Types::SoftwareRevenue
Specifies details of a customer's procurement terms.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the opportunity.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#catalog ⇒ String
Specifies the catalog associated with the request. This field takes
a string value from a predefined list: AWS or Sandbox. The
catalog determines which environment the opportunity information is
retrieved from. Use AWS to retrieve opportunities in the Amazon
Web Services catalog, and Sandbox to retrieve opportunities in a
secure and isolated testing environment.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
DateTime when the Opportunity was last created.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#customer ⇒ Types::Customer
Specifies details of the customer associated with the Opportunity.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Read-only, system generated Opportunity unique identifier.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
DateTime when the opportunity was last modified.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#life_cycle ⇒ Types::LifeCycle
An object that contains lifecycle details for the Opportunity.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#marketing ⇒ Types::Marketing
An object that contains marketing details for the Opportunity.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#national_security ⇒ String
Indicates whether the Opportunity pertains to a national security
project. This field must be set to true only when the customer's
industry is Government. Additional privacy and security measures
apply during the review and management process for opportunities
marked as NationalSecurity.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#opportunity_team ⇒ Array<Types::Contact>
Represents the internal team handling the opportunity. Specify the members involved in collaborating on this opportunity within the partner's organization.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#opportunity_type ⇒ String
Specifies the opportunity type as renewal, new, or expansion.
Opportunity types:
-
New opportunity: Represents a new business opportunity with a potential customer that's not previously engaged with your solutions or services.
-
Renewal opportunity: Represents an opportunity to renew an existing contract or subscription with a current customer, which helps to ensure service continuity.
-
Expansion opportunity: Represents an opportunity to expand the scope of a customer's contract or subscription, either by adding new services or increasing the volume of existing services.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#partner_opportunity_identifier ⇒ String
Specifies the opportunity's unique identifier in the partner's CRM system. This value is essential to track and reconcile because it's included in the outbound payload sent back to the partner.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#primary_needs_from_aws ⇒ Array<String>
Identifies the type of support the partner needs from Amazon Web Services.
Valid values:
-
Cosell—Architectural Validation: Confirmation from Amazon Web Services that the partner's proposed solution architecture is aligned with Amazon Web Services best practices and poses minimal architectural risks.
-
Cosell—Business Presentation: Request Amazon Web Services seller's participation in a joint customer presentation.
-
Cosell—Competitive Information: Access to Amazon Web Services competitive resources and support for the partner's proposed solution.
-
Cosell—Pricing Assistance: Connect with an Amazon Web Services seller for support situations where a partner may be receiving an upfront discount on a service (for example: EDP deals).
-
Cosell—Technical Consultation: Connect with an Amazon Web Services Solutions Architect to address the partner's questions about the proposed solution.
-
Cosell—Total Cost of Ownership Evaluation: Assistance with quoting different cost savings of proposed solutions on Amazon Web Services versus on-premises or a traditional hosting environment.
-
Cosell—Deal Support: Request Amazon Web Services seller's support to progress the opportunity (for example: joint customer call, strategic positioning).
-
Cosell—Support for Public Tender/RFx: Opportunity related to the public sector where the partner needs Amazon Web Services RFx support.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#project ⇒ Types::Project
An object that contains project details summary for the
Opportunity.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#related_entity_identifiers ⇒ Types::RelatedEntityIdentifiers
Provides information about the associations of other entities with
the opportunity. These entities include identifiers for
AWSProducts, Partner Solutions, and AWSMarketplaceOffers.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |
#software_revenue ⇒ Types::SoftwareRevenue
Specifies details of a customer's procurement terms. Required only for partners in eligible programs.
2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2692 class GetOpportunityResponse < Struct.new( :catalog, :primary_needs_from_aws, :national_security, :partner_opportunity_identifier, :customer, :project, :opportunity_type, :marketing, :software_revenue, :id, :arn, :last_modified_date, :created_date, :related_entity_identifiers, :life_cycle, :opportunity_team) SENSITIVE = [] include Aws::Structure end |