Class: Aws::PartnerCentralSelling::Types::GetProspectingFromEngagementTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::GetProspectingFromEngagementTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Represents the request structure for retrieving the status and results of a prospecting task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog associated with the task.
-
#task_identifier ⇒ String
The unique identifier of the prospecting task to retrieve.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog associated with the task. Specify ‘AWS` for production environments and `Sandbox` for testing and development purposes. The value must match the catalog used when the task was created.
2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2721 class GetProspectingFromEngagementTaskRequest < Struct.new( :catalog, :task_identifier) SENSITIVE = [] include Aws::Structure end |
#task_identifier ⇒ String
The unique identifier of the prospecting task to retrieve. This value is returned in the ‘TaskId` field of the `StartProspectingFromEngagementTask` response.
2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2721 class GetProspectingFromEngagementTaskRequest < Struct.new( :catalog, :task_identifier) SENSITIVE = [] include Aws::Structure end |