Class: Aws::PartnerCentralSelling::Types::Invitation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

The Invitation structure represents an invitation exchanged between partners and AWS. It includes a message, receiver information, and a payload providing context for the invitation.

Constant Summary collapse

SENSITIVE =
[:message]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

A message accompanying the invitation.

Returns:

  • (String)


2935
2936
2937
2938
2939
2940
2941
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2935

class Invitation < Struct.new(
  :message,
  :receiver,
  :payload)
  SENSITIVE = [:message]
  include Aws::Structure
end

#payloadTypes::Payload

Contains the data payload associated with the Engagement Invitation. This payload includes essential details related to the AWS opportunity and is used by partners to evaluate whether to accept or reject the engagement.

Returns:



2935
2936
2937
2938
2939
2940
2941
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2935

class Invitation < Struct.new(
  :message,
  :receiver,
  :payload)
  SENSITIVE = [:message]
  include Aws::Structure
end

#receiverTypes::Receiver

Represents the entity that received the Engagement Invitation, including account and company details. This field is essential for tracking the partner who is being invited to collaborate.

Returns:



2935
2936
2937
2938
2939
2940
2941
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 2935

class Invitation < Struct.new(
  :message,
  :receiver,
  :payload)
  SENSITIVE = [:message]
  include Aws::Structure
end