Class: Aws::PartnerCentralSelling::Types::LeadAddress
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::LeadAddress
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
The address information for a lead customer, including city, state or region, postal code, and country code.
Constant Summary collapse
- SENSITIVE =
[:country_code]
Instance Attribute Summary collapse
-
#city ⇒ String
The city of the lead customer's address.
-
#country_code ⇒ String
The country code of the lead customer's address.
-
#postal_code ⇒ String
The postal code of the lead customer's address.
-
#state_or_region ⇒ String
The state or region of the lead customer's address.
Instance Attribute Details
#city ⇒ String
The city of the lead customer's address.
3211 3212 3213 3214 3215 3216 3217 3218 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3211 class LeadAddress < Struct.new( :city, :postal_code, :state_or_region, :country_code) SENSITIVE = [:country_code] include Aws::Structure end |
#country_code ⇒ String
The country code of the lead customer's address.
3211 3212 3213 3214 3215 3216 3217 3218 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3211 class LeadAddress < Struct.new( :city, :postal_code, :state_or_region, :country_code) SENSITIVE = [:country_code] include Aws::Structure end |
#postal_code ⇒ String
The postal code of the lead customer's address.
3211 3212 3213 3214 3215 3216 3217 3218 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3211 class LeadAddress < Struct.new( :city, :postal_code, :state_or_region, :country_code) SENSITIVE = [:country_code] include Aws::Structure end |
#state_or_region ⇒ String
The state or region of the lead customer's address.
3211 3212 3213 3214 3215 3216 3217 3218 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 3211 class LeadAddress < Struct.new( :city, :postal_code, :state_or_region, :country_code) SENSITIVE = [:country_code] include Aws::Structure end |