Class: Aws::PartnerCentralSelling::Types::ListSolutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::ListSolutionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog associated with the request.
-
#category ⇒ Array<String>
Filters the solutions based on the category to which they belong.
-
#identifier ⇒ Array<String>
Filters the solutions based on their unique identifier.
-
#max_results ⇒ Integer
The maximum number of results returned by a single call.
-
#next_token ⇒ String
A pagination token used to retrieve the next set of results in subsequent calls.
-
#sort ⇒ Types::SolutionSort
Object that configures sorting done on the response.
-
#status ⇒ Array<String>
Filters solutions based on their status.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog associated with the request. This field takes a string value from a predefined list: AWS or Sandbox. The catalog determines which environment the solutions are listed in. Use AWS to list solutions in the Amazon Web Services catalog, and Sandbox to list solutions in a secure and isolated testing environment.
4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697 class ListSolutionsRequest < Struct.new( :catalog, :max_results, :next_token, :sort, :status, :identifier, :category) SENSITIVE = [] include Aws::Structure end |
#category ⇒ Array<String>
Filters the solutions based on the category to which they belong. This allows partners to search for solutions within specific categories, such as Software, Consulting, or ‘Managed Services`.
4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697 class ListSolutionsRequest < Struct.new( :catalog, :max_results, :next_token, :sort, :status, :identifier, :category) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ Array<String>
Filters the solutions based on their unique identifier. Use this filter to retrieve specific solutions by providing the solution’s identifier for accurate results.
4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697 class ListSolutionsRequest < Struct.new( :catalog, :max_results, :next_token, :sort, :status, :identifier, :category) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results returned by a single call. This value must be provided in the next call to retrieve the next set of results.
Default: 20
4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697 class ListSolutionsRequest < Struct.new( :catalog, :max_results, :next_token, :sort, :status, :identifier, :category) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token used to retrieve the next set of results in subsequent calls. This token is included in the response only if there are additional result pages available.
4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697 class ListSolutionsRequest < Struct.new( :catalog, :max_results, :next_token, :sort, :status, :identifier, :category) SENSITIVE = [] include Aws::Structure end |
#sort ⇒ Types::SolutionSort
Object that configures sorting done on the response. Default Sort.SortBy is Identifier.
4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697 class ListSolutionsRequest < Struct.new( :catalog, :max_results, :next_token, :sort, :status, :identifier, :category) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Array<String>
Filters solutions based on their status. This filter helps partners manage their solution portfolios effectively.
4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4697 class ListSolutionsRequest < Struct.new( :catalog, :max_results, :next_token, :sort, :status, :identifier, :category) SENSITIVE = [] include Aws::Structure end |