Class: Aws::PartnerCentralSelling::Types::ListSolutionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::ListSolutionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A pagination token used to retrieve the next set of results in subsequent calls.
-
#solution_summaries ⇒ Array<Types::SolutionBase>
An array with minimal details for solutions matching the request criteria.
Instance Attribute Details
#next_token ⇒ String
A pagination token used to retrieve the next set of results in subsequent calls. This token is included in the response only if there are additional result pages available.
4722 4723 4724 4725 4726 4727 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4722 class ListSolutionsResponse < Struct.new( :solution_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#solution_summaries ⇒ Array<Types::SolutionBase>
An array with minimal details for solutions matching the request criteria.
4722 4723 4724 4725 4726 4727 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 4722 class ListSolutionsResponse < Struct.new( :solution_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |