Class: Aws::PartnerCentralSelling::Types::OpportunitySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::OpportunitySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
An object that contains an ‘Opportunity`’s subset of fields.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the opportunity.
-
#catalog ⇒ String
Specifies the catalog associated with the opportunity, either ‘AWS` or `Sandbox`.
-
#created_date ⇒ Time
‘DateTime` when the `Opportunity` was last created.
-
#customer ⇒ Types::CustomerSummary
An object that contains the ‘Opportunity`’s customer details.
-
#id ⇒ String
Read-only, system-generated ‘Opportunity` unique identifier.
-
#last_modified_date ⇒ Time
‘DateTime` when the `Opportunity` was last modified.
-
#life_cycle ⇒ Types::LifeCycleSummary
An object that contains the ‘Opportunity`’s lifecycle details.
-
#opportunity_type ⇒ String
Specifies opportunity type as a renewal, new, or expansion.
-
#partner_opportunity_identifier ⇒ String
Specifies the ‘Opportunity`’s unique identifier in the partner’s CRM system.
-
#project ⇒ Types::ProjectSummary
An object that contains the ‘Opportunity`’s project details summary.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the opportunity. This globally unique identifier can be used for IAM policies and cross-service references.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |
#catalog ⇒ String
Specifies the catalog associated with the opportunity, either ‘AWS` or `Sandbox`. This indicates the environment in which the opportunity is managed.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
‘DateTime` when the `Opportunity` was last created.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |
#customer ⇒ Types::CustomerSummary
An object that contains the ‘Opportunity`’s customer details.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Read-only, system-generated ‘Opportunity` unique identifier.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
‘DateTime` when the `Opportunity` was last modified.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |
#life_cycle ⇒ Types::LifeCycleSummary
An object that contains the ‘Opportunity`’s lifecycle details.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |
#opportunity_type ⇒ String
Specifies opportunity type as a renewal, new, or expansion.
Opportunity types:
-
New Opportunity: Represents a new business opportunity with a potential customer that’s not previously engaged with your solutions or services.
-
Renewal Opportunity: Represents an opportunity to renew an existing contract or subscription with a current customer, ensuring continuity of service.
-
Expansion Opportunity: Represents an opportunity to expand the scope of an existing contract or subscription, either by adding new services or increasing the volume of existing services for a current customer.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |
#partner_opportunity_identifier ⇒ String
Specifies the ‘Opportunity`’s unique identifier in the partner’s CRM system. This value is essential to track and reconcile because it’s included in the outbound payload sent back to the partner. It allows partners to link an opportunity to their CRM.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |
#project ⇒ Types::ProjectSummary
An object that contains the ‘Opportunity`’s project details summary.
5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5053 class OpportunitySummary < Struct.new( :catalog, :id, :arn, :partner_opportunity_identifier, :opportunity_type, :last_modified_date, :created_date, :life_cycle, :customer, :project) SENSITIVE = [] include Aws::Structure end |