Class: Aws::PartnerCentralSelling::Types::OpportunitySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

An object that contains an ‘Opportunity`’s subset of fields.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) for the opportunity. This globally unique identifier can be used for IAM policies and cross-service references.

Returns:

  • (String)


5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#catalogString

Specifies the catalog associated with the opportunity, either ‘AWS` or `Sandbox`. This indicates the environment in which the opportunity is managed.

Returns:

  • (String)


5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateTime

‘DateTime` when the `Opportunity` was last created.

Returns:

  • (Time)


5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#customerTypes::CustomerSummary

An object that contains the ‘Opportunity`’s customer details.



5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Read-only, system-generated ‘Opportunity` unique identifier.

Returns:

  • (String)


5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

‘DateTime` when the `Opportunity` was last modified.

Returns:

  • (Time)


5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#life_cycleTypes::LifeCycleSummary

An object that contains the ‘Opportunity`’s lifecycle details.



5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#opportunity_typeString

Specifies opportunity type as a renewal, new, or expansion.

Opportunity types:

  • New Opportunity: Represents a new business opportunity with a potential customer that’s not previously engaged with your solutions or services.

  • Renewal Opportunity: Represents an opportunity to renew an existing contract or subscription with a current customer, ensuring continuity of service.

  • Expansion Opportunity: Represents an opportunity to expand the scope of an existing contract or subscription, either by adding new services or increasing the volume of existing services for a current customer.

Returns:

  • (String)


5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#partner_opportunity_identifierString

Specifies the ‘Opportunity`’s unique identifier in the partner’s CRM system. This value is essential to track and reconcile because it’s included in the outbound payload sent back to the partner. It allows partners to link an opportunity to their CRM.

Returns:

  • (String)


5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end

#projectTypes::ProjectSummary

An object that contains the ‘Opportunity`’s project details summary.



5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5026

class OpportunitySummary < Struct.new(
  :catalog,
  :id,
  :arn,
  :partner_opportunity_identifier,
  :opportunity_type,
  :last_modified_date,
  :created_date,
  :life_cycle,
  :customer,
  :project)
  SENSITIVE = []
  include Aws::Structure
end