Class: Aws::PartnerCentralSelling::Types::OpportunitySummaryView

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Provides a comprehensive view of an opportunity summary, including lifecycle information, team details, opportunity type, primary needs from AWS, and associated project information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customerTypes::Customer

An object that contains the customer’s ‘Account` and `Contact`.

Returns:



5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
5417
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5407

class OpportunitySummaryView < Struct.new(
  :opportunity_type,
  :lifecycle,
  :opportunity_team,
  :primary_needs_from_aws,
  :customer,
  :project,
  :related_entity_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycleTypes::LifeCycleForView

Contains information about the opportunity’s lifecycle, including its current stage, status, and important dates such as creation and last modification times.



5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
5417
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5407

class OpportunitySummaryView < Struct.new(
  :opportunity_type,
  :lifecycle,
  :opportunity_team,
  :primary_needs_from_aws,
  :customer,
  :project,
  :related_entity_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#opportunity_teamArray<Types::Contact>

Represents the internal team handling the opportunity. Specify the members involved in collaborating on an opportunity within the partner’s organization.

Returns:



5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
5417
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5407

class OpportunitySummaryView < Struct.new(
  :opportunity_type,
  :lifecycle,
  :opportunity_team,
  :primary_needs_from_aws,
  :customer,
  :project,
  :related_entity_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#opportunity_typeString

Specifies the opportunity type.

Returns:

  • (String)


5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
5417
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5407

class OpportunitySummaryView < Struct.new(
  :opportunity_type,
  :lifecycle,
  :opportunity_team,
  :primary_needs_from_aws,
  :customer,
  :project,
  :related_entity_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#primary_needs_from_awsArray<String>

Identifies the type of support the partner needs from AWS.

Returns:

  • (Array<String>)


5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
5417
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5407

class OpportunitySummaryView < Struct.new(
  :opportunity_type,
  :lifecycle,
  :opportunity_team,
  :primary_needs_from_aws,
  :customer,
  :project,
  :related_entity_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#projectTypes::ProjectView

Contains summary information about the project associated with the opportunity, including project name, description, timeline, and other relevant details.

Returns:



5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
5417
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5407

class OpportunitySummaryView < Struct.new(
  :opportunity_type,
  :lifecycle,
  :opportunity_team,
  :primary_needs_from_aws,
  :customer,
  :project,
  :related_entity_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

This field provides the associations’ information for other entities with the opportunity. These entities include identifiers for ‘AWSProducts`, `Partner Solutions`, and `AWSMarketplaceOffers`.



5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
5417
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5407

class OpportunitySummaryView < Struct.new(
  :opportunity_type,
  :lifecycle,
  :opportunity_team,
  :primary_needs_from_aws,
  :customer,
  :project,
  :related_entity_identifiers)
  SENSITIVE = []
  include Aws::Structure
end