Class: Aws::PartnerCentralSelling::Types::OpportunitySummaryView
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::OpportunitySummaryView
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Provides a comprehensive view of an opportunity summary, including lifecycle information, team details, opportunity type, primary needs from AWS, and associated project information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer ⇒ Types::Customer
An object that contains the customer’s ‘Account` and `Contact`.
-
#lifecycle ⇒ Types::LifeCycleForView
Contains information about the opportunity’s lifecycle, including its current stage, status, and important dates such as creation and last modification times.
-
#opportunity_team ⇒ Array<Types::Contact>
Represents the internal team handling the opportunity.
-
#opportunity_type ⇒ String
Specifies the opportunity type.
-
#primary_needs_from_aws ⇒ Array<String>
Identifies the type of support the partner needs from AWS.
-
#project ⇒ Types::ProjectView
Contains summary information about the project associated with the opportunity, including project name, description, timeline, and other relevant details.
-
#related_entity_identifiers ⇒ Types::RelatedEntityIdentifiers
This field provides the associations’ information for other entities with the opportunity.
Instance Attribute Details
#customer ⇒ Types::Customer
An object that contains the customer’s ‘Account` and `Contact`.
5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5083 class OpportunitySummaryView < Struct.new( :opportunity_type, :lifecycle, :opportunity_team, :primary_needs_from_aws, :customer, :project, :related_entity_identifiers) SENSITIVE = [] include Aws::Structure end |
#lifecycle ⇒ Types::LifeCycleForView
Contains information about the opportunity’s lifecycle, including its current stage, status, and important dates such as creation and last modification times.
5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5083 class OpportunitySummaryView < Struct.new( :opportunity_type, :lifecycle, :opportunity_team, :primary_needs_from_aws, :customer, :project, :related_entity_identifiers) SENSITIVE = [] include Aws::Structure end |
#opportunity_team ⇒ Array<Types::Contact>
Represents the internal team handling the opportunity. Specify the members involved in collaborating on an opportunity within the partner’s organization.
5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5083 class OpportunitySummaryView < Struct.new( :opportunity_type, :lifecycle, :opportunity_team, :primary_needs_from_aws, :customer, :project, :related_entity_identifiers) SENSITIVE = [] include Aws::Structure end |
#opportunity_type ⇒ String
Specifies the opportunity type.
5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5083 class OpportunitySummaryView < Struct.new( :opportunity_type, :lifecycle, :opportunity_team, :primary_needs_from_aws, :customer, :project, :related_entity_identifiers) SENSITIVE = [] include Aws::Structure end |
#primary_needs_from_aws ⇒ Array<String>
Identifies the type of support the partner needs from AWS.
5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5083 class OpportunitySummaryView < Struct.new( :opportunity_type, :lifecycle, :opportunity_team, :primary_needs_from_aws, :customer, :project, :related_entity_identifiers) SENSITIVE = [] include Aws::Structure end |
#project ⇒ Types::ProjectView
Contains summary information about the project associated with the opportunity, including project name, description, timeline, and other relevant details.
5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5083 class OpportunitySummaryView < Struct.new( :opportunity_type, :lifecycle, :opportunity_team, :primary_needs_from_aws, :customer, :project, :related_entity_identifiers) SENSITIVE = [] include Aws::Structure end |
#related_entity_identifiers ⇒ Types::RelatedEntityIdentifiers
This field provides the associations’ information for other entities with the opportunity. These entities include identifiers for ‘AWSProducts`, `Partner Solutions`, and `AWSMarketplaceOffers`.
5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5083 class OpportunitySummaryView < Struct.new( :opportunity_type, :lifecycle, :opportunity_team, :primary_needs_from_aws, :customer, :project, :related_entity_identifiers) SENSITIVE = [] include Aws::Structure end |