Class: Aws::PartnerCentralSelling::Types::Payload
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::Payload
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Payload is a union - when making an API calls you must set exactly one of the members.
Payload is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Payload corresponding to the set member.
Contains the data payload associated with the Engagement Invitation. This payload includes essential details related to the AWS opportunity and is used by partners to evaluate whether to accept or reject the engagement.
Direct Known Subclasses
Defined Under Namespace
Classes: LeadInvitation, OpportunityInvitation, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lead_invitation ⇒ Types::LeadInvitationPayload
Specifies the details of the lead invitation within the Engagement Invitation payload.
-
#opportunity_invitation ⇒ Types::OpportunityInvitationPayload
Specifies the details of the opportunity invitation within the Engagement Invitation payload.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#lead_invitation ⇒ Types::LeadInvitationPayload
Specifies the details of the lead invitation within the Engagement Invitation payload. This data helps partners understand the lead context, customer information, and interaction history for the lead opportunity from AWS.
5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 5454 5455 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5444 class Payload < Struct.new( :opportunity_invitation, :lead_invitation, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpportunityInvitation < Payload; end class LeadInvitation < Payload; end class Unknown < Payload; end end |
#opportunity_invitation ⇒ Types::OpportunityInvitationPayload
Specifies the details of the opportunity invitation within the Engagement Invitation payload. This data helps partners understand the context, scope, and expected involvement for the opportunity from AWS.
5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 5454 5455 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5444 class Payload < Struct.new( :opportunity_invitation, :lead_invitation, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpportunityInvitation < Payload; end class LeadInvitation < Payload; end class Unknown < Payload; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
5444 5445 5446 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5444 def unknown @unknown end |