Class: Aws::PartnerCentralSelling::Types::Payload

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Note:

Payload is a union - when making an API calls you must set exactly one of the members.

Note:

Payload is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Payload corresponding to the set member.

Contains the data payload associated with the Engagement Invitation. This payload includes essential details related to the AWS opportunity and is used by partners to evaluate whether to accept or reject the engagement.

Direct Known Subclasses

LeadInvitation, OpportunityInvitation, Unknown

Defined Under Namespace

Classes: LeadInvitation, OpportunityInvitation, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lead_invitationTypes::LeadInvitationPayload

Specifies the details of the lead invitation within the Engagement Invitation payload. This data helps partners understand the lead context, customer information, and interaction history for the lead opportunity from AWS.



5147
5148
5149
5150
5151
5152
5153
5154
5155
5156
5157
5158
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5147

class Payload < Struct.new(
  :opportunity_invitation,
  :lead_invitation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpportunityInvitation < Payload; end
  class LeadInvitation < Payload; end
  class Unknown < Payload; end
end

#opportunity_invitationTypes::OpportunityInvitationPayload

Specifies the details of the opportunity invitation within the Engagement Invitation payload. This data helps partners understand the context, scope, and expected involvement for the opportunity from AWS.



5147
5148
5149
5150
5151
5152
5153
5154
5155
5156
5157
5158
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5147

class Payload < Struct.new(
  :opportunity_invitation,
  :lead_invitation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpportunityInvitation < Payload; end
  class LeadInvitation < Payload; end
  class Unknown < Payload; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5147
5148
5149
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5147

def unknown
  @unknown
end