Class: Aws::PartnerCentralSelling::Types::Receiver
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::Receiver
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Receiver is a union - when making an API calls you must set exactly one of the members.
Receiver is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Receiver corresponding to the set member.
Represents the entity that received the Engagement Invitation, including account and company details. This field is essential for tracking the partner who is being invited to collaborate.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account ⇒ Types::AccountReceiver
Specifies the AWS account of the partner who received the Engagement Invitation.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#account ⇒ Types::AccountReceiver
Specifies the AWS account of the partner who received the Engagement Invitation. This field is used to track the invitation recipient within the AWS ecosystem.
6130 6131 6132 6133 6134 6135 6136 6137 6138 6139 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6130 class Receiver < Struct.new( :account, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Account < Receiver; end class Unknown < Receiver; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6130 6131 6132 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6130 def unknown @unknown end |