Class: Aws::PartnerCentralSelling::Types::ResourceSnapshotPayload

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Note:

ResourceSnapshotPayload is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ResourceSnapshotPayload corresponding to the set member.

Represents the payload of a resource snapshot. This structure is designed to accommodate different types of resource snapshots, currently supporting opportunity summaries.

Defined Under Namespace

Classes: AwsOpportunitySummaryFullView, OpportunitySummary, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_opportunity_summary_full_viewTypes::AwsOpportunitySummaryFullView

Provides a comprehensive view of AwsOpportunitySummaryFullView template.



6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6350

class ResourceSnapshotPayload < Struct.new(
  :opportunity_summary,
  :aws_opportunity_summary_full_view,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpportunitySummary < ResourceSnapshotPayload; end
  class AwsOpportunitySummaryFullView < ResourceSnapshotPayload; end
  class Unknown < ResourceSnapshotPayload; end
end

#opportunity_summaryTypes::OpportunitySummaryView

An object that contains an ‘opportunity`’s subset of fields.



6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6350

class ResourceSnapshotPayload < Struct.new(
  :opportunity_summary,
  :aws_opportunity_summary_full_view,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpportunitySummary < ResourceSnapshotPayload; end
  class AwsOpportunitySummaryFullView < ResourceSnapshotPayload; end
  class Unknown < ResourceSnapshotPayload; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6350
6351
6352
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6350

def unknown
  @unknown
end