Class: Aws::PartnerCentralSelling::Types::ResourceSnapshotSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::ResourceSnapshotSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Provides a concise summary of a resource snapshot, including its unique identifier and version information. This structure is used to quickly reference and identify specific versions of resource snapshots.
Constant Summary collapse
- SENSITIVE =
[:created_by]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot.
-
#created_by ⇒ String
The AWS account ID of the entity that owns the resource from which the snapshot was created.
-
#resource_id ⇒ String
The identifier of the specific resource snapshotted.
-
#resource_snapshot_template_name ⇒ String
The name of the template used to create the snapshot.
-
#resource_type ⇒ String
The type of resource snapshotted.
-
#revision ⇒ Integer
The revision number of the snapshot.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot. This globally unique identifier can be used for cross-service references and in IAM policies.
5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5809 class ResourceSnapshotSummary < Struct.new( :arn, :revision, :resource_type, :resource_id, :resource_snapshot_template_name, :created_by) SENSITIVE = [:created_by] include Aws::Structure end |
#created_by ⇒ String
The AWS account ID of the entity that owns the resource from which the snapshot was created.
5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5809 class ResourceSnapshotSummary < Struct.new( :arn, :revision, :resource_type, :resource_id, :resource_snapshot_template_name, :created_by) SENSITIVE = [:created_by] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the specific resource snapshotted. The format might vary depending on the ResourceType.
5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5809 class ResourceSnapshotSummary < Struct.new( :arn, :revision, :resource_type, :resource_id, :resource_snapshot_template_name, :created_by) SENSITIVE = [:created_by] include Aws::Structure end |
#resource_snapshot_template_name ⇒ String
The name of the template used to create the snapshot.
5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5809 class ResourceSnapshotSummary < Struct.new( :arn, :revision, :resource_type, :resource_id, :resource_snapshot_template_name, :created_by) SENSITIVE = [:created_by] include Aws::Structure end |
#resource_type ⇒ String
The type of resource snapshotted.
5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5809 class ResourceSnapshotSummary < Struct.new( :arn, :revision, :resource_type, :resource_id, :resource_snapshot_template_name, :created_by) SENSITIVE = [:created_by] include Aws::Structure end |
#revision ⇒ Integer
The revision number of the snapshot. This integer value is incremented each time the snapshot is updated, allowing for version tracking of the resource snapshot.
5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 5809 class ResourceSnapshotSummary < Struct.new( :arn, :revision, :resource_type, :resource_id, :resource_snapshot_template_name, :created_by) SENSITIVE = [:created_by] include Aws::Structure end |