Class: Aws::PartnerCentralSelling::Types::StartEngagementFromOpportunityTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_submissionTypes::AwsSubmission

Indicates the level of AWS involvement in the opportunity. This field helps track AWS participation throughout the engagement, such as providing technical support, deal assistance, and sales support.



6738
6739
6740
6741
6742
6743
6744
6745
6746
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6738

class StartEngagementFromOpportunityTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :aws_submission,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#catalogString

Specifies the catalog in which the engagement is tracked. Acceptable values include ‘AWS` for production and `Sandbox` for testing environments.

Returns:

  • (String)


6738
6739
6740
6741
6742
6743
6744
6745
6746
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6738

class StartEngagementFromOpportunityTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :aws_submission,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique token provided by the client to help ensure the idempotency of the request. It helps prevent the same task from being performed multiple times.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


6738
6739
6740
6741
6742
6743
6744
6745
6746
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6738

class StartEngagementFromOpportunityTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :aws_submission,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the opportunity from which the engagement task is to be initiated. This helps ensure that the task is applied to the correct opportunity.

Returns:

  • (String)


6738
6739
6740
6741
6742
6743
6744
6745
6746
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6738

class StartEngagementFromOpportunityTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :aws_submission,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A map of the key-value pairs of the tag or tags to assign.

Returns:



6738
6739
6740
6741
6742
6743
6744
6745
6746
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6738

class StartEngagementFromOpportunityTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :aws_submission,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end