Class: Aws::PartnerCentralSelling::Types::StartEngagementFromOpportunityTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::StartEngagementFromOpportunityTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_submission ⇒ Types::AwsSubmission
Indicates the level of AWS involvement in the opportunity.
-
#catalog ⇒ String
Specifies the catalog in which the engagement is tracked.
-
#client_token ⇒ String
A unique token provided by the client to help ensure the idempotency of the request.
-
#identifier ⇒ String
The unique identifier of the opportunity from which the engagement task is to be initiated.
-
#tags ⇒ Array<Types::Tag>
A map of the key-value pairs of the tag or tags to assign.
Instance Attribute Details
#aws_submission ⇒ Types::AwsSubmission
Indicates the level of AWS involvement in the opportunity. This field helps track AWS participation throughout the engagement, such as providing technical support, deal assistance, and sales support.
6098 6099 6100 6101 6102 6103 6104 6105 6106 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6098 class StartEngagementFromOpportunityTaskRequest < Struct.new( :catalog, :client_token, :identifier, :aws_submission, :tags) SENSITIVE = [] include Aws::Structure end |
#catalog ⇒ String
Specifies the catalog in which the engagement is tracked. Acceptable values include ‘AWS` for production and `Sandbox` for testing environments.
6098 6099 6100 6101 6102 6103 6104 6105 6106 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6098 class StartEngagementFromOpportunityTaskRequest < Struct.new( :catalog, :client_token, :identifier, :aws_submission, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique token provided by the client to help ensure the idempotency of the request. It helps prevent the same task from being performed multiple times.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6098 6099 6100 6101 6102 6103 6104 6105 6106 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6098 class StartEngagementFromOpportunityTaskRequest < Struct.new( :catalog, :client_token, :identifier, :aws_submission, :tags) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the opportunity from which the engagement task is to be initiated. This helps ensure that the task is applied to the correct opportunity.
6098 6099 6100 6101 6102 6103 6104 6105 6106 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6098 class StartEngagementFromOpportunityTaskRequest < Struct.new( :catalog, :client_token, :identifier, :aws_submission, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A map of the key-value pairs of the tag or tags to assign.
6098 6099 6100 6101 6102 6103 6104 6105 6106 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6098 class StartEngagementFromOpportunityTaskRequest < Struct.new( :catalog, :client_token, :identifier, :aws_submission, :tags) SENSITIVE = [] include Aws::Structure end |