Class: Aws::PartnerCentralSelling::Types::StartEngagementFromOpportunityTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::StartEngagementFromOpportunityTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engagement_id ⇒ String
The identifier of the newly created Engagement.
-
#engagement_invitation_id ⇒ String
The identifier of the new Engagement invitation.
-
#message ⇒ String
If the task fails, this field contains a detailed message describing the failure and possible recovery steps.
-
#opportunity_id ⇒ String
Returns the original opportunity identifier passed in the request, which is the unique identifier for the opportunity created in the partner’s system.
-
#reason_code ⇒ String
Indicates the reason for task failure using an enumerated code.
-
#resource_snapshot_job_id ⇒ String
The identifier of the resource snapshot job created to add the opportunity resource snapshot to the Engagement.
-
#start_time ⇒ Time
The timestamp indicating when the task was initiated.
-
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task, used for tracking and managing the task within AWS.
-
#task_id ⇒ String
The unique identifier of the task, used to track the task’s progress.
-
#task_status ⇒ String
Indicates the current status of the task.
Instance Attribute Details
#engagement_id ⇒ String
The identifier of the newly created Engagement. Only populated if TaskStatus is COMPLETE.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#engagement_invitation_id ⇒ String
The identifier of the new Engagement invitation. Only populated if TaskStatus is COMPLETE.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
If the task fails, this field contains a detailed message describing the failure and possible recovery steps.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#opportunity_id ⇒ String
Returns the original opportunity identifier passed in the request, which is the unique identifier for the opportunity created in the partner’s system.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#reason_code ⇒ String
Indicates the reason for task failure using an enumerated code.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#resource_snapshot_job_id ⇒ String
The identifier of the resource snapshot job created to add the opportunity resource snapshot to the Engagement. Only populated if TaskStatus is COMPLETE
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp indicating when the task was initiated. The format follows RFC 3339 section 5.6.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task, used for tracking and managing the task within AWS.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task, used to track the task’s progress. This value follows a specific pattern: ‘^oit-13$`.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |
#task_status ⇒ String
Indicates the current status of the task. Valid values include ‘IN_PROGRESS`, `COMPLETE`, and `FAILED`.
6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6162 class StartEngagementFromOpportunityTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :engagement_invitation_id) SENSITIVE = [] include Aws::Structure end |