Class: Aws::PartnerCentralSelling::Types::StartOpportunityFromEngagementTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

Specifies the catalog in which the opportunity creation task is executed. Acceptable values include ‘AWS` for production and `Sandbox` for testing environments.

Returns:

  • (String)


6259
6260
6261
6262
6263
6264
6265
6266
6267
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259

class StartOpportunityFromEngagementTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :context_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique token provided by the client to help ensure the idempotency of the request. It helps prevent the same task from being performed multiple times.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


6259
6260
6261
6262
6263
6264
6265
6266
6267
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259

class StartOpportunityFromEngagementTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :context_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#context_identifierString

The unique identifier of the engagement context from which to create the opportunity. This specifies the specific contextual information within the engagement that will be used for opportunity creation.

Returns:

  • (String)


6259
6260
6261
6262
6263
6264
6265
6266
6267
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259

class StartOpportunityFromEngagementTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :context_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the engagement from which the opportunity creation task is to be initiated. This helps ensure that the task is applied to the correct engagement.

Returns:

  • (String)


6259
6260
6261
6262
6263
6264
6265
6266
6267
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259

class StartOpportunityFromEngagementTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :context_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A map of the key-value pairs of the tag or tags to assign.

Returns:



6259
6260
6261
6262
6263
6264
6265
6266
6267
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259

class StartOpportunityFromEngagementTaskRequest < Struct.new(
  :catalog,
  :client_token,
  :identifier,
  :context_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end