Class: Aws::PartnerCentralSelling::Types::StartOpportunityFromEngagementTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::StartOpportunityFromEngagementTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
Specifies the catalog in which the opportunity creation task is executed.
-
#client_token ⇒ String
A unique token provided by the client to help ensure the idempotency of the request.
-
#context_identifier ⇒ String
The unique identifier of the engagement context from which to create the opportunity.
-
#identifier ⇒ String
The unique identifier of the engagement from which the opportunity creation task is to be initiated.
-
#tags ⇒ Array<Types::Tag>
A map of the key-value pairs of the tag or tags to assign.
Instance Attribute Details
#catalog ⇒ String
Specifies the catalog in which the opportunity creation task is executed. Acceptable values include ‘AWS` for production and `Sandbox` for testing environments.
6259 6260 6261 6262 6263 6264 6265 6266 6267 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique token provided by the client to help ensure the idempotency of the request. It helps prevent the same task from being performed multiple times.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6259 6260 6261 6262 6263 6264 6265 6266 6267 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#context_identifier ⇒ String
The unique identifier of the engagement context from which to create the opportunity. This specifies the specific contextual information within the engagement that will be used for opportunity creation.
6259 6260 6261 6262 6263 6264 6265 6266 6267 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the engagement from which the opportunity creation task is to be initiated. This helps ensure that the task is applied to the correct engagement.
6259 6260 6261 6262 6263 6264 6265 6266 6267 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A map of the key-value pairs of the tag or tags to assign.
6259 6260 6261 6262 6263 6264 6265 6266 6267 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6259 class StartOpportunityFromEngagementTaskRequest < Struct.new( :catalog, :client_token, :identifier, :context_identifier, :tags) SENSITIVE = [] include Aws::Structure end |