Class: Aws::PartnerCentralSelling::Types::StartOpportunityFromEngagementTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::StartOpportunityFromEngagementTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context_id ⇒ String
The unique identifier of the engagement context used to create the opportunity.
-
#engagement_id ⇒ String
The unique identifier of the engagement from which the opportunity was created.
-
#message ⇒ String
If the task fails, this field contains a detailed message describing the failure and possible recovery steps.
-
#opportunity_id ⇒ String
The unique identifier of the opportunity created as a result of the task.
-
#reason_code ⇒ String
Indicates the reason for task failure using an enumerated code.
-
#resource_snapshot_job_id ⇒ String
The identifier of the resource snapshot job created as part of the opportunity creation process.
-
#start_time ⇒ Time
The timestamp indicating when the task was initiated.
-
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task, used for tracking and managing the task within AWS.
-
#task_id ⇒ String
The unique identifier of the task, used to track the task's progress.
-
#task_status ⇒ String
Indicates the current status of the task.
Instance Attribute Details
#context_id ⇒ String
The unique identifier of the engagement context used to create the opportunity.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#engagement_id ⇒ String
The unique identifier of the engagement from which the opportunity was created.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
If the task fails, this field contains a detailed message describing the failure and possible recovery steps.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#opportunity_id ⇒ String
The unique identifier of the opportunity created as a result of the task. This field is populated when the task is completed successfully.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#reason_code ⇒ String
Indicates the reason for task failure using an enumerated code.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#resource_snapshot_job_id ⇒ String
The identifier of the resource snapshot job created as part of the opportunity creation process.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp indicating when the task was initiated. The format follows RFC 3339 section 5.6.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task, used for tracking and managing the task within AWS.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task, used to track the task's progress.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |
#task_status ⇒ String
Indicates the current status of the task.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6947 class StartOpportunityFromEngagementTaskResponse < Struct.new( :task_id, :task_arn, :start_time, :task_status, :message, :reason_code, :opportunity_id, :resource_snapshot_job_id, :engagement_id, :context_id) SENSITIVE = [] include Aws::Structure end |