Class: Aws::PartnerCentralSelling::Types::ThrottlingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

This error occurs when there are too many requests sent. Review the provided quotas and adapt your usage to avoid throttling.

This error occurs when there are too many requests sent. Review the provided Quotas and retry after the provided delay.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


7238
7239
7240
7241
7242
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7238

class ThrottlingException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end