Class: Aws::PartnerCentralSelling::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralSelling::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralselling/types.rb
Overview
This error occurs when there are too many requests sent. Review the provided quotas and adapt your usage to avoid throttling.
This error occurs when there are too many requests sent. Review the provided [Quotas] and retry after the provided delay.
[1]: docs.aws.amazon.com/partner-central/latest/selling-api/quotas.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
7202 7203 7204 7205 7206 |
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7202 class ThrottlingException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |