Class: Aws::PartnerCentralSelling::Types::UpdateEngagementContextPayload

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Note:

UpdateEngagementContextPayload is a union - when making an API calls you must set exactly one of the members.

Represents the updated payload of an engagement context. The structure of this payload varies based on the context type being updated.

Direct Known Subclasses

CustomerProject, Lead, ProspectingResult, Unknown

Defined Under Namespace

Classes: CustomerProject, Lead, ProspectingResult, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_projectTypes::CustomerProjectsContext

The CustomerProjects structure in Engagements offers a flexible framework for managing customer-project relationships. It supports multiple customers per Engagement and multiple projects per customer, while also allowing for customers without projects and projects without specific customers.

All Engagement members have full visibility of customers and their associated projects, enabling the capture of relevant context even when project details are not fully defined. This structure also facilitates targeted invitations, allowing partners to focus on specific customers and their business problems when sending Engagement invitations.



7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7266

class UpdateEngagementContextPayload < Struct.new(
  :lead,
  :customer_project,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Lead < UpdateEngagementContextPayload; end
  class CustomerProject < UpdateEngagementContextPayload; end
  class ProspectingResult < UpdateEngagementContextPayload; end
  class Unknown < UpdateEngagementContextPayload; end
end

#leadTypes::UpdateLeadContext

Contains updated information about a lead when the context type is “Lead”. This field is present only when updating a lead context within the engagement.



7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7266

class UpdateEngagementContextPayload < Struct.new(
  :lead,
  :customer_project,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Lead < UpdateEngagementContextPayload; end
  class CustomerProject < UpdateEngagementContextPayload; end
  class ProspectingResult < UpdateEngagementContextPayload; end
  class Unknown < UpdateEngagementContextPayload; end
end

#prospecting_resultTypes::ProspectingResult

Contains updated prospecting result data when the context type is “ProspectingResult”. This field includes enriched data and insights that the system generates when a partner runs an autonomous prospecting job on leads.



7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7266

class UpdateEngagementContextPayload < Struct.new(
  :lead,
  :customer_project,
  :prospecting_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Lead < UpdateEngagementContextPayload; end
  class CustomerProject < UpdateEngagementContextPayload; end
  class ProspectingResult < UpdateEngagementContextPayload; end
  class Unknown < UpdateEngagementContextPayload; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7266
7267
7268
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7266

def unknown
  @unknown
end