Class: Aws::PartnerCentralSelling::Types::UpdateEngagementContextRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalogString

Specifies the catalog associated with the engagement context update request. This field takes a string value from a predefined list: ‘AWS` or `Sandbox`. The catalog determines which environment the engagement context is updated in.

Returns:

  • (String)


6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6611

class UpdateEngagementContextRequest < Struct.new(
  :catalog,
  :engagement_identifier,
  :context_identifier,
  :engagement_last_modified_at,
  :type,
  :payload)
  SENSITIVE = []
  include Aws::Structure
end

#context_identifierString

The unique identifier of the specific engagement context to be updated. This ensures that the correct context within the engagement is modified.

Returns:

  • (String)


6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6611

class UpdateEngagementContextRequest < Struct.new(
  :catalog,
  :engagement_identifier,
  :context_identifier,
  :engagement_last_modified_at,
  :type,
  :payload)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_identifierString

The unique identifier of the ‘Engagement` containing the context to be updated. This parameter ensures the context update is applied to the correct engagement.

Returns:

  • (String)


6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6611

class UpdateEngagementContextRequest < Struct.new(
  :catalog,
  :engagement_identifier,
  :context_identifier,
  :engagement_last_modified_at,
  :type,
  :payload)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_last_modified_atTime

The timestamp when the engagement was last modified, used for optimistic concurrency control. This helps prevent conflicts when multiple users attempt to update the same engagement simultaneously.

Returns:

  • (Time)


6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6611

class UpdateEngagementContextRequest < Struct.new(
  :catalog,
  :engagement_identifier,
  :context_identifier,
  :engagement_last_modified_at,
  :type,
  :payload)
  SENSITIVE = []
  include Aws::Structure
end

#payloadTypes::UpdateEngagementContextPayload

Contains the updated contextual information for the engagement. The structure of this payload varies based on the context type specified in the Type field.



6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6611

class UpdateEngagementContextRequest < Struct.new(
  :catalog,
  :engagement_identifier,
  :context_identifier,
  :engagement_last_modified_at,
  :type,
  :payload)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Specifies the type of context being updated within the engagement. This field determines the structure and content of the context payload being modified.

Returns:

  • (String)


6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6611

class UpdateEngagementContextRequest < Struct.new(
  :catalog,
  :engagement_identifier,
  :context_identifier,
  :engagement_last_modified_at,
  :type,
  :payload)
  SENSITIVE = []
  include Aws::Structure
end