Class: Aws::PartnerCentralSelling::Types::UpdateEngagementContextResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#context_idString

The unique identifier of the engagement context that was updated.

Returns:

  • (String)


6640
6641
6642
6643
6644
6645
6646
6647
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6640

class UpdateEngagementContextResponse < Struct.new(
  :engagement_id,
  :engagement_arn,
  :engagement_last_modified_at,
  :context_id)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_arnString

The Amazon Resource Name (ARN) of the updated engagement.

Returns:

  • (String)


6640
6641
6642
6643
6644
6645
6646
6647
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6640

class UpdateEngagementContextResponse < Struct.new(
  :engagement_id,
  :engagement_arn,
  :engagement_last_modified_at,
  :context_id)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_idString

The unique identifier of the engagement that was updated.

Returns:

  • (String)


6640
6641
6642
6643
6644
6645
6646
6647
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6640

class UpdateEngagementContextResponse < Struct.new(
  :engagement_id,
  :engagement_arn,
  :engagement_last_modified_at,
  :context_id)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_last_modified_atTime

The timestamp when the engagement context was last modified.

Returns:

  • (Time)


6640
6641
6642
6643
6644
6645
6646
6647
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 6640

class UpdateEngagementContextResponse < Struct.new(
  :engagement_id,
  :engagement_arn,
  :engagement_last_modified_at,
  :context_id)
  SENSITIVE = []
  include Aws::Structure
end