Class: Aws::PartnerCentralSelling::Types::UpdateLeadContext

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralselling/types.rb

Overview

Updates the context information for a lead with qualification status, customer details, and interaction data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customerTypes::LeadCustomer

Updated customer information associated with the lead.

Returns:



7381
7382
7383
7384
7385
7386
7387
7388
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7381

class UpdateLeadContext < Struct.new(
  :qualification_status,
  :customer,
  :interaction,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#insightsTypes::LeadInsights

Insights that AI generates and associates with the lead. These insights provide automated analysis to help partners assess the lead quality and readiness.

Returns:



7381
7382
7383
7384
7385
7386
7387
7388
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7381

class UpdateLeadContext < Struct.new(
  :qualification_status,
  :customer,
  :interaction,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#interactionTypes::LeadInteraction

Updated interaction details for the lead context.



7381
7382
7383
7384
7385
7386
7387
7388
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7381

class UpdateLeadContext < Struct.new(
  :qualification_status,
  :customer,
  :interaction,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#qualification_statusString

The updated qualification status of the lead.

Returns:

  • (String)


7381
7382
7383
7384
7385
7386
7387
7388
# File 'lib/aws-sdk-partnercentralselling/types.rb', line 7381

class UpdateLeadContext < Struct.new(
  :qualification_status,
  :customer,
  :interaction,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end